#
# spec file for package perl-Mojolicious
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mojolicious
Name:           perl-Mojolicious
Version:        9.31
Release:        bp154.2.3.1
License:        Artistic-2.0
Summary:        Real-time web framework
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SR/SRI/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(IO::Socket::IP) >= 0.37
BuildRequires:  perl(Sub::Util) >= 1.41
Requires:       perl(IO::Socket::IP) >= 0.37
Requires:       perl(Sub::Util) >= 1.41
%{perl_requires}

%description
An amazing real-time web framework built on top of the powerful Mojo web
development toolkit. With support for RESTful routes, plugins, commands,
Perl-ish templates, content negotiation, session management, form
validation, testing framework, static file server, 'CGI'/'PSGI' detection,
first class Unicode support and much more for you to discover.

Take a look at our excellent documentation in Mojolicious::Guides!

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README.md
%license LICENSE

%changelog
* Wed Dec 21 2022 Tina Müller <timueller+perl@suse.de>
- updated to 9.31
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.31  2022-12-21
  - This release contains fixes for security issues, everybody should upgrade!
  - Removed experimental status from links method in Mojo::Headers.
  - Added tls_options attribute to Mojo::UserAgent. (heikojansen)
  - Fixed multiple "<script>" parsing issues in Mojo::DOM.
  - Fixed a sporadic warning in Mojo::UserAgent. (s1037989)
  - Fixed UNIX domain socket support in Mojo::UserAgent debug feature. (s1037989)
  - Fixed a bug in Mojo::DOM where strings like "<.>" were considered valid tags.
* Wed Nov 23 2022 Tina Müller <timueller+perl@suse.de>
- updated to 9.30
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.30  2022-11-22
  - Added EXPERIMENTAL support for parsing and generating Link headers.
  - Added EXPERIMENTAL links method to Mojo::Headers.
  - Added EXPERIMENTAL header_params function to Mojo::Util.
  9.29  2022-11-11
  - Fixed a bug where promises returning promises were not handled correctly. (batman)
* Sat Oct 15 2022 Tina Müller <timueller+perl@suse.de>
- updated to 9.28
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.28  2022-09-12
  - Fixed a bug where async/await use could result in unhandled promise warnings. (batman)
* Tue Sep 13 2022 Tina Müller <timueller+perl@suse.de>
- updated to 9.27
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.27  2022-09-10
  - Added support for static assets.
  - Added support for JSON and plain text exceptions.
  - Removed experimental status from capture method in Mojo::Log.
  - Added asset_dir attribute to Mojolicious::Static.
  - Added asset_path method to Mojolicious::Static.
  - Added url_for_asset method to Mojolicious::Controller.
  - Added reply->html_exception, reply->html_not_found, reply->json_exception, reply->json_not_found,
    reply->http_exception, reply->http_not_found, reply->txt_exception and reply->txt_not_found helpers to
    Mojolicious::Plugin::DefaultHelpers.
  - Added asset_tag helper to Mojolicious::Plugin::TagHelpers.
  - Fixed a bug where async rendering did not work properly in the before_dispatch hook. (andrii-suse)
* Tue May 24 2022 Tina Müller <timueller+perl@suse.de>
- updated to 9.26
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.26  2022-05-20
  - Added EXPERIMENTAL capture method to Mojo::Log.
* Fri Apr 29 2022 Tina Müller <timueller+perl@suse.de>
- updated to 9.25
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.25  2022-04-25
  - Improved Mojolicious::Renderer to throw an exception if rendering is attempted more than once.
* Tue Apr 19 2022 Tina Müller <timueller+perl@suse.de>
- updated to 9.24
  see /usr/share/doc/packages/perl-Mojolicious/Changes
* Sat Mar 26 2022 Tina Müller <timueller+perl@suse.de>
- updated to 9.23
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.23  2021-03-25
  - Enable gzip compression by default in Mojolicious::Renderer.
* Fri Oct 22 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.22
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.22  2021-10-16
  - Added a referer method to Mojo::Headers, as an alias for the referrer method.
  - Fixed response status log message to use the "trace" log level instead of "debug".
* Sat Aug 14 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.21
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.21  2021-08-13
  - Added EXPERIMENTAL supprt for top-level await to Mojo::Promise.
  - Updated Future::AsyncAwait requirement to 0.52 for new fatures and bug fixes.
  - Improved *_attr and *_text methods in Test::Mojo to return undef instead of empty string for values that do not
    exist. (tim-2)
  - Fixed Mojo::DOM not to auto-close tags in <svg> and <math> blocks. (mkende)
* Tue Aug 10 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.20
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.20  2021-08-09
  - Added trace log level to Mojo::Log.
  - Changed default log level in Mojo::Log from "debug" to "trace" and moved all built-in "debug" log messages to the
    level "trace". That will allow for the "debug" level to be used exclusively for user defined log messages.
* Wed Jun  2 2021 Tina Müller <tina.mueller@suse.com>
- updated to 9.19
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.19  2021-06-01
  - This release contains fixes for security issues, everybody should upgrade!
  - Swiched from HMAC-SHA1 to HMAC-SHA256 for signed cookies. Note that this means that all sessions will be reset.
  - Improved signed cookie based sessions to pad short values, to make it harder to brute force attack the application
    secret. (jberger)
* Mon May 24 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.18
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.18  2021-05-09
  - Remove Font Awesome from distribution.
* Wed Apr 14 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.17
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.17  2021-04-12
  - Deprecated ?format=* parameter in favor of ?_format=* for content negotiation in Mojolicious::Renderer.
* Sat Apr 10 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.16
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.16  2021-04-08
  - Added support for format inheritance.
  - Improved Mojo::Server::CGI with support for before_server_start hook.
  9.15  2021-03-30
  - Improved form generator in Mojo::UserAgent::Transactor to allow custom Content-Disposition headers.
* Wed Mar 24 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.14
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.14  2021-03-23
  - Added EXPERIMENTAL support for :text pseudo-class to Mojo::DOM::CSS.
  9.13  2021-03-22
  - Improved request_id attribute in Mojo::Message::Request to be a little more unique.
  - Fixed Mojolicious::Plugin::Mount to share the logger of the host application.
* Sun Mar 21 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.12
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.12  2021-03-21
  - Improved mojo script startup time slightly with a Mojo::HelloWorld optimization.
  - Improved design of built-in templates.
  9.11  2021-03-20
  - This release contains fixes for security issues, everybody should upgrade!
  - Disabled format detection by default to fix vulnerabilities in many Mojolicious applications. That means some of
    your routes that previously matched "/foo" and "/foo.json", will only match "/foo" after upgrading. From now on you
    will have to explicitly declare the formats your routes are allowed to handle.
    [#] /foo
    [#] /foo.html
    [#] /foo.json
    $r->get('/foo')->to('bar#yada');
    becomes
    $r->get('/foo' => [format => ['html', 'json']])->to('bar#yada', format => undef);
    And if you are certain that your application is not vulnerable, you also have the option to re-enable format
    detection for a route and all its nested routes. Due to the high risk of vulnerabilities, this feature is going to
    be removed again in a future release however.
    my $active = $r->any([format => 1]);
    $active->get('/foo')->to('Test#first');
    $active->put('/bar')->to('Test#second');
  - Improved built-in templates not to show embedded apps in the stash snapshot.
  - Improved built-in development not found page to include tooltips with the compiled regular expressions for each
    route.
  - Improved Mojo::UserAgent to include "Content-Length: 0" with non-GET requests for better compatibility with broken
    web servers.
* Tue Mar 16 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.10
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.10  2021-03-14
  - Fixed top-level --help and -h options in Mojolicious::Commands.
  9.09  2021-03-13
  - Added comma_separated filter to Mojolicious::Validator.
  - Fixed built-in templates to be a bit more responsive.
  - Fixed filter list handling in Mojolicious::Validator::Validation.
  9.08  2021-03-12
  - Fixed a bug in Test::Mojo where Test::Mojo->new($app) would not work correctly.
  9.07  2021-03-11
  - Improved config override feature to work for Mojolicious::Lite applications.
  - Improved Mojo::UserAgent performance slightly by not including unnecessary "Content-Length: 0" request headers.
* Mon Mar  8 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.03
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.03  2021-03-05
  - Fixed a bug in Mojo::Transaction::WebSocket where finish event handlers would not always get the same number of
    arguments passed.
* Tue Mar  2 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.02
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.02  2021-02-17
  - Fixed finally method in Mojo::Promise to deal correctly with promises returned by the handler.
  - Improved Mojo::Server::Daemon to include random ports in the "Web application available at ..." message.
* Wed Feb 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.01
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.01  2021-02-16
  - Added EXPERIMENTAL color attribute to Mojo::Log.
  - Added EXPERIMENTAL MOJO_LOG_COLOR environment variable to Mojo::Log.
  - Fixed Windows support of network_contains function in Mojo::Util. (jberger)
* Mon Feb 15 2021 Tina Müller <timueller+perl@suse.de>
- updated to 9.0
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  9.0  2021-02-14
  - Code name "Waffle", this is a major release.
  - Added support for deployment specific plugins.
  - Removed Mojo::IOLoop::Delay.
  - Removed hidden attribute from Mojolicious::Routes.
  - Removed hide and is_hidden methods from Mojolicious::Routes.
  - Removed deprecated success method from Mojo::Transaction.
  - Removed deprecated detour, over, route and via methods from Mojolicious::Routes::Route.
  - Removed deprecated local_address method from Mojo::UserAgent.
  - Removed deprecated tls_ciphers, tls_protocols, tls_verify and tls_version options from Mojo::IOLoop::TLS.
  - Removed deprecated local_address option from Mojo::IOLoop::Client.
  - Removed deprecated config stash value.
  - Changed Mojo::Log to join mutiple log messages with a whitespace instead of a newline.
  - Added is_reserved method to Mojolicious::Routes::Route.
  - Improved Mojolicious::Routes to disallow the use of reserved stash values, such as "/:action", in route patterns.
  - Improved Mojolicious::Routes to throw exceptions for missing controllers.
  - Improved Mojolicious::Routes to throw exceptions for routes with controllers but without action.
  - Improved Mojolicious::Routes to disallow namespace without controller for routing.
  - Improved Mojolicious::Routes to die if auto rendering failed.
  - Improved render method in Mojolicious::Controller to die if no response could be rendered.
  - Improved reply->static helper to die if the requested file does not exist.
  - Improved contextual logging feature in Mojo::Log not to concatenate log messages and context.
  - Improved all_text method in Mojo::DOM to exclude "<script>" and "<style>" from text extraction in HTML documents.
  - Improved error messages in config plugins to be more consistent.
* Sun Feb  7 2021 Tina Müller <timueller+perl@suse.de>
- updated to 8.73
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.73  2021-02-05
  - Removed finally keyword from check function in Mojo::Exception.
  - Changed arguments of check function in Mojo::Exception to be easier to use with Perl 5.34 try/catch.
  - Removed experimental status from preload_namespaces attribute in Mojolicious.
  - Removed experimental status from any, map, timer and timeout methods in Mojo::Promise.
  - Removed experimental status from extname method in Mojo::File.
  - Removed experimental status from warmup method in Mojolicious.
  - Removed experimental status from load_classes function in Mojo::Loader.
  - Removed experimental status from Mojo::DynamicMethods. Still summons old gods, use at your own risk!
  - Removed experimental status from before_command hook in Mojolicious.
  - Added silent attribute to Mojo::Server::Morbo.
* Thu Jan 28 2021 Tina Müller <timueller+perl@suse.de>
- updated to 8.72
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.72  2021-01-26
  - Deprecated Mojo::UserAgent::local_address in favor of Mojo::UserAgent::socket_options.
  - Deprecated local_address option of connect method in Mojo::IOLoop::Client in favor of socket_options.
  - Deprecated tls_protocols option of connect method in Mojo::IOLoop::Client in favor of tls_options.
  - Deprecated tls_verify option of connect method in Mojo::IOLoop::Client in favor of tls_options.
  - Deprecated tls_protocols option of negotiate method in Mojo::IOLoop::TLS in favor of tls_options.
  - Deprecated tls_ciphers option of negotiate method in Mojo::IOLoop::TLS in favor of tls_options.
  - Deprecated tls_verify option of negotiate method in Mojo::IOLoop::TLS in favor of tls_options.
  - Deprecated tls_version option of negotiate method in Mojo::IOLoop::TLS in favor of tls_options.
  - Deprecated tls_ciphers option of listen method in Mojo::IOLoop::Server in favor of tls_options.
  - Deprecated tls_verify option of listen method in Mojo::IOLoop::Server in favor of tls_options.
  - Deprecated tls_version option of listen method in Mojo::IOLoop::Server in favor of tls_options.
  - Added support for trusted reverse proxies. (jberger)
  - Added network_contains function to Mojo::Util. (jberger)
  - Added trusted_proxies attribute to Mojo::Server and Mojo::Message::Request. (jberger)
  - Added socket_options method to Mojo::UserAgent.
  - Added build_server method to Mojolicious::Command::daemon and Mojolicious::Command::prefork. (jberger)
  - Added trusted_proxies option to Hynotoad. (jberger)
  - Added socket_options and tls_options options to connect method in Mojo::IOLoop::Client.
  - Added tls_options option to negotiate method in Mojo::IOLoop::TLS.
* Mon Jan 18 2021 Tina Müller <timueller+perl@suse.de>
- updated to 8.71
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.71  2021-01-17
  - Added EXPERIMENTAL freeze option to reset method in Mojo::IOLoop.
  - Improved Mojo::IOLoop::Subprocess not to close connections after fork.
* Thu Dec 31 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.70
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.70  2020-12-29
  - Fixed top-level help command in Mojolicious::Commands. (schelcj)
  8.69  2020-12-28
  - Improved design of built-in templates.
  8.68  2020-12-27
  - Updated built-in templates with new responsive design from mojolicious.org.
  - Fixed a bug in Mojo::Message::Request that resulted in duplicate request ids for Mojo::Server::Prefork workers.
* Sun Dec  6 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.67
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.67  2020-12-04
  - Deprecated Mojolicious::Routes::Route::route in favor of Mojolicious::Routes::Route::any.
  - Deprecated Mojolicious::Routes::Route::over in favor of Mojolicious::Routes::Route::requires.
  - Deprecated Mojolicious::Routes::Route::via in favor of Mojolicious::Routes::Route::methods.
  - Deprecated Mojolicious::Routes::Route::detour.
  - Added methods and requires methods to Mojolicious::Routes::Route.
  - Improved Mojolicious::Commands to throw an exception for invalid commands.
* Tue Dec  1 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.66
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.66  2020-11-28
  - Deprecated logging to "log/$mode.log" (if a log directory exists) in Mojolicious. The default will simply be STDERR
    in the future.
  - Added support for preloading controllers and other classes during startup of Mojolicious applications.
  - Added EXPERIMENTAL preload_namespaces attribute to Mojolicious.
  - Added EXPERIMENTAL warmup method to Mojolicious.
  - Added EXPERIMENTAL load_classes function to Mojo::Loader.
  - Removed experimental status from humanize_bytes method in Mojo::ByteStream.
  - Removed experimental status from humanize_bytes function in Mojo::Util.
  - Improved find_modules function in Mojo::Loader with recursive option.
  - Improved Mojo::DOM::CSS to throw exceptions for unknown CSS selectors.
  - Fixed a bug in Mojolicious::Commands where help messages would not be displayed correctly for some commands.
    (kiwiroy)
  - Fixed a bug in Mojolicious::Routes::Pattern where type_start was treated as a regex. (Grinnz)
* Thu Nov 12 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.65
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.65  2020-11-10
  - Added generate dockerfile command. (tianon)
  - Improved cookbook with container deployment recipe.
  - Improved security of secure_compare function in Mojo::Util. (robrwo)
  - Fixed all generated code to consistently use a *::Sandbox class, instead of *::SandBox.
* Sat Nov  7 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.64
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.64  2020-11-01
  - Replaced prettify.js with highlight.js. (zakame)
  - Fixed a bug in Mojo::DOM where the tree root would be checked for all pseudo-classes.
  - Fixed a redefined subroutine warning in eval command. (elmar)
* Wed Oct 14 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.63
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.63  2020-10-11
  - Improved Mojo::IOLoop::Subprocess to ensure a clean exit even if something unexpected happens in the forked
    process.
* Tue Oct 13 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.62
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.62  2020-10-10
  - Improved commands to exit with a usage message on unknown options.
* Sat Oct  3 2020 Oliver Kurz <okurz@suse.com>
- updated to 8.61
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.61  2020-10-01
  - Fixed fork-safety feature in Mojo::UserAgent to work with more than one fork.
  - Fixed reset method in Mojo::IOLoop to not interfere with close events anymore, since that resulted in leaks.
* Mon Sep 28 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.60
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.60  2020-09-27
  - Improved reset method in Mojo::IOLoop to prevent close event to be emitted in affected streams. (kiwiroy)
  - Improved cookbook with Envoy deployment recipe. (zakame)
* Mon Sep 14 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.59
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.59  2020-09-05
  - Added l function to ojo. (kiwiroy)
  - Added MOJO_PROMISE_DEBUG environment variable to Mojo::Promise.
* Tue Aug 11 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.58
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.58  2020-08-05
  - Improved app and lite_app generators to use templates with subroutine signatures.
  - Updated all documentation to use subroutine signatures. (kiwiroy)
* Sat Jul 18 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.57
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.57  2020-07-16
  - Added support for YAML config files.
  - Added module Mojolicious::Plugin::NotYAMLConfig.
  - Improved app generator command to use a YAML config file.
  - Fixed a bug in proxy helpers that caused response content to be ignored in some cases. (mohawk2)
  - Fixed attr_is bug in Test::Mojo that prevented false value comparisons from working correctly. (tim-2)
* Sat Jun 27 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.56
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.56  2020-06-19
  - Fixed a bug that prevented "%% end, begin" to work in Mojo::Template. (jberger)
* Thu Jun 18 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.55
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.55  2020-06-18
  - Fixed a regression in Mojo::DOM::CSS that caused some selectors to not be valid anymore.
* Mon Jun 15 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.54
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.54  2020-06-14
  - Added EXPERIMENTAL support for :scope and :has pseudo-classes to Mojo::DOM::CSS. (Eckankar, kraih)
  - Fixed a bug in Mojo::DOM where select and ruby elements were parsed incorrectly.
  - Fixed a but in Mojo::UserAgent::Transactor that prevented compression settings to be inherited across redirects.
  - Fixed a bug where Mojolicious templates could not use the continue Perl keyword.
* Thu Jun 11 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.53
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.53  2020-06-09
  - Added EXPERIMENTAL extname method to Mojo::File.
  - Fixed a bug in Mojolicious::Types where dotfiles would be considered file extensions.
* Thu Jun  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 8.52
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.52  2020-06-01
  - Updated project metadata.
  - Fixed a bug in Mojo::Asset::Memory where the upgrade event could not change the temporary directory.
* Mon Jun  1 2020 Tina Müller <timueller+perl@suse.de>
  updated to 8.51
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.51  2020-05-30
  - Improved map efficiency in Mojo::Promise. (mst)
  - Improved more tests to use subtests. (veesh)
  - Improved .perltidyrc with more modern settings.
* Tue May 26 2020 Tina Müller <timueller+perl@suse.de>
  updated to 8.50
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.50  2020-05-23
  - Increased Perl version requirement to 5.16.0. This is just a first step
    however, at some point in the not so distant future we will increase the
    Perl version requirement to 5.20.0 for full subroutine signatures support.
  - Improved Mojo::Base to enable the Perl 5.16 feature bundle with
    "unicode_strings", "unicode_eval", "evalbytes", "current_sub" and "fc".
  8.43  2020-05-20
  - Removed deprecated argument handling from Mojo::Promise::new.
  - Removed experimental status from all_settled method in Mojo::Promise.
  - Removed experimental status from content_type and file_type methods in
    Mojolicious::Types.
  - Removed experimental status from cleanup event in Mojo::IOLoop::Subprocess.
  - Switched from Storable to JSON serialization for Mojo::IOLoop::Subprocess
    IPC to increase efficiency.
  - Added exit_code method to Mojo::IOLoop::Subprocess.
  - Improved Mojo::Promise to warn when an unhandled rejected promise is
    destroyed.
  - Fixed a bug where the resolve class method in Mojo::Promise would
    unnecessarily create new promises.
  - Fixed a promise chaining bug in Mojo::Promise. (karjala)
* Tue May  5 2020 Tina Müller <timueller+perl@suse.de>
  updated to 8.42
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.42  2020-05-04
  - This release contains fixes for security issues, everybody should upgrade!
  - Added EXPERIMENTAL support for :any-link pseudo-class to Mojo::DOM::CSS.
  - Added EXPERIMENTAL support for case-sensitive attribute selectors like
    [foo="bar" s] to Mojo::DOM::CSS
  - Renamed experimental :matches pseudo-class to :is in Mojo::DOM::CSS.
  - Fixed a security issue that allowed for _method query parameters to be used
    with GET requests.
  - Fixed a bug in Mojo::DOM::CSS where the case-sensitivity identifier was
    case-sensitive.
* Sat May  2 2020 Tina Müller <timueller+perl@suse.de>
  updated to 8.41
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.41  2020-04-30
  - Improved Mojolicious::Commands to treat commands like
    "mojo generate lite_app" as "mojo generate lite-app".
* Thu Apr 23 2020 <timueller+perl@suse.de>
- updated to 8.40
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.40  2020-04-23
  - Fixed support for disabling the inactivity timeout in Mojo::UserAgent.
* Wed Apr 22 2020 <timueller+perl@suse.de>
- updated to 8.39
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.39  2020-04-22
  - Fixed a bug in Mojo::Server::Daemon where active connections could get the
    keep-alive timeout assigned instead of the inactivity timeout.
  - Fixed a race condition in Mojo::UserAgent where test servers would close
    connections prematurely.
* Wed Apr 22 2020 <timueller+perl@suse.de>
- updated to 8.38
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.38  2020-04-21
  - Added run_p method to Mojo::IOLoop::Subprocess. (batman)
* Mon Apr 20 2020 <timueller+perl@suse.de>
- updated to 8.37
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.37  2020-04-19
  - Added keep_alive_timeout attribute to Mojo::Server::Daemon.
  - Added -k options to daemon and prefork commands.
  - Added keep_alive_timeout setting to Hypnotoad.
  - Increased various default timeouts because keep_alive_timeout takes over
    some of their previous responsibility.
  - Improved timeout setting performance significantly in Mojo::IOLoop::Stream.
  - Improved again method in Mojo::Reactor, Mojo::Reactor::EV and
    Mojo::Reactor::Poll to allow changing the invocation time of active timers.
  - Fixed support for 425 status in Mojo::Message::Response.
* Thu Apr  2 2020 <timueller+perl@suse.de>
- updated to 8.36
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.36  2020-03-31
  - Added handler attribute to Test::Mojo.
  - Added test method to Test::Mojo.
  - Improved Test::Mojo to allow for extensions to be tested more easily.
  - Improved request_id attribute in Mojo::Message::Request to be a little more
    unique. (mst)
* Sun Mar 22 2020 <timueller+perl@suse.de>
- updated to 8.35
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.35  2020-03-20
  - Added not_empty filter to Mojolicious::Validator.
* Tue Mar 17 2020 <timueller+perl@suse.de>
- updated to 8.34
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.34  2020-03-16
  - Removed experimental status from proxy->get_p, proxy->post_p and
    proxy->start_p helpers in Mojolicious::Plugin::DefaultHelpers.
  - Removed experimental status from compress and min_compress_size attributes
    in Mojolicious::Renderer.
  - Removed experimental status from high_water_mark attribute in
    Mojo::IOLoop::Stream.
  - Removed experimental status from respond method in Mojolicious::Renderer.
  - Removed experimental status from bytes_waiting and can_write methods in
    Mojo::IOLoop::Stream.
  - Removed experimental status from dehop method in Mojo::Headers.
  - Removed experimental status from scope_guard function in Mojo::Util.
  - Improved size check in Mojolicious::Validator to only require one argument.
  - Fixed Mojolicious::Validator to also validate empty string values instead of
    ignoring them. This behaviour had caused a lot of confusion in the past.
  - Fixed plugin generator not to use an __END__ section.
* Wed Feb 12 2020 <timueller+perl@suse.de>
- updated to 8.33
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.33  2020-02-11
  - Added EXPERIMENTAL humanize_bytes function to Mojo::Util. (kraih, coolo)
  - Added EXPERIMENTAL humanize_bytes method to Mojo::ByteStream.
  - Updated Future::AsyncAwait requirement to 0.36 for better tests. (ilmari)
* Mon Jan 20 2020 <timueller+perl@suse.de>
- updated to 8.32
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.32  2020-01-18
  - Changed experimental -async flag to -async_await in Mojo::Base, because of a
    Perl quirk that Future::AsyncAwait can't handle itself.
  - Fixed a bug where the -async_await flag in Mojo::Base would not load
    Mojo::Promise.
* Wed Jan 15 2020 <timueller+perl@suse.de>
- updated to 8.31
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.31  2020-01-14
  - Added attr_is, attr_isnt, attr_like and attr_unlike methods to Test::Mojo.
    (pau4o)
  - Improved is_fresh method in Mojolicious::Static with support for weak etags.
    (ether)
* Fri Jan 10 2020 <timueller+perl@suse.de>
- updated to 8.30
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.30  2020-01-07
  - Switch from Future::AsyncAwait::Frozen to Future::AsyncAwait for async/await
    support.
* Sun Dec 29 2019 <timueller+perl@suse.de>
- updated to 8.29
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.29  2019-12-28
  - Improved async/await support to work in many more cases, such as WebSocket
    handlers.
  8.28  2019-12-26
  - Added EXPERIMENTAL support for async/await (with -async Mojo::Base flag).
  - Added EXPERIMENTAL all_settled and any methods to Mojo::Promise.
* Thu Dec  5 2019 <timueller+perl@suse.de>
- updated to 8.27
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.27  2019-12-04
  - Added EXPERIMENTAL before_command hook.
  - Added EXPERIMENTAL scope_guard function to Mojo::Util.
  - Removed experimental status from context method in Mojo::Log.
  - Changed default MIME type of content_type method in Mojolicious::Types to
    application/octet-stream. (aitap)
* Mon Nov  4 2019 <timueller+perl@suse.de>
- updated to 8.26
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.26  2019-11-02
  - Removed deprecated slice method from Mojo::Collection.
  - Moved HTML entities from Mojo::Util into a separate file. (rage311)
  - Changed how the state of the event loop is determined in Mojo::Reactor::EV
    to be more consistent with Mojo::Reactor::Poll.
* Mon Sep 30 2019 <timueller+perl@suse.de>
- updated to 8.25
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.25  2019-09-29
  - Added curfile function to Mojo::File. (Grinnz)
* Thu Sep 12 2019 <timueller+perl@suse.de>
- updated to 8.24
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.24  2019-09-11
  - Added EXPERIMENTAL context method to Mojo::Log.
  - Added EXPERIMENTAL cleanup event to Mojo::IOLoop::Subprocess.
  - Added log helper to Mojolicious::Plugin::DefaultHelpers.
  - Improved log messages generated by Mojolicious to include request ids when
    possible
* Tue Aug 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 8.23
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.23  2019-08-12
  - Updated Cpanel::JSON::XS requirement to 4.09 for duplicate keys support.
    (Grinnz)
  - Added head and tail methods to Mojo::Collection. (Grinnz)
  - Improved Mojo::File not to allow undefined values in paths.
* Fri Jul 19 2019 Stephan Kulow <coolo@suse.com>
- updated to 8.22
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.22  2019-07-17
  - Fixed a bug where Mojo::Exception would not stringify correctly for error
    messages that end with a newline.
  - Fixed Mojo::Exception to append file and line number to stringified error
    messages that do not end with a newline.
* Mon Jul 15 2019 Oliver Kurz <okurz@suse.com>
- updated to 8.21
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.21  2019-07-13
  - Undeprecated Mojo::Exception::verbose.
  - Added support for MOJO_EXCEPTION_VERBOSE environment variable.
  - Improved built in templates to use the same stack trace format as
    Mojo::Exception.
  8.20  2019-07-08
  - Improved check function in Mojo::Exception to match regular expressions
    against stringified exception objects too.
  - Improved num check in Mojolicious::Validator to accept negative numbers.
    (kiwiroy)
  8.19  2019-07-07
  - Deprecated Mojo::Exception::verbose.
  - Added EXPERIMENTAL check and raise functions to Mojo::Exception.
  - Added -f option to generate plugin command.
  - Improved inspect method in Mojo::Exception to be safe to call more than
    once.
  - Fixed various stack trace bugs in Mojo::Exception, so your error messages
    and stack traces can look slightly different than before.
  - Fixed bugs in reply->exception helper that could result in exceptions
    without error message.
  - Fixed daemonize exception handling in Mojo::Server. (skaji)
* Sat Jun 29 2019 Stephan Kulow <coolo@suse.com>
- updated to 8.18
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.18  2019-06-28
  - Welcome to the Mojolicious core team CandyAngel, Christopher Rasch-Olsen
    Raa and Dan Book.
  - Deprecated the use of the config stash value and $config variable in
    templates by Mojolicious::Plugin::Config. You can use the config helper
    instead. Unfortunately there is no good way to warn users, so this
    deprecation will be in effect until the next major release.
  - Deprecated Mojo::Collection::slice since nobody remembers anymore what its
    intended purpose was.
  - Added EXPERIMENTAL proxy->get_p, proxy->post_p and proxy->start_p helpers to
    Mojolicious::Plugin::DefaultHelpers.
  - Added EXPERIMENTAL dehop method to Mojo::Headers.
  - Added EXPERIMENTAL bytes_waiting and can_write methods to
    Mojo::IOLoop::Stream.
  - Added EXPERIMENTAL high_water_mark attribute to Mojo::IOLoop::Stream.
  - Updated bundled TLS certificate.
  - Improved Mojo::Base flags not to require a certain order.
  - Improved clone performance in Mojo::Headers by 100%%.
  - Improved streaming response performance slightly.
  - Fixed a typo in the 425 status message in Mojo::Message::Response.
    (CandyAngel)
  - Fixed a missing deprecation warning in Mojo::Promise. (marcus)
* Fri May 24 2019 Stephan Kulow <coolo@suse.com>
- updated to 8.17
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.17  2019-05-23
  - Fixed a bug in Mojo::UserAgent where the request timeout would not work for
    keep-alive requests. (ilmari)
* Mon May 20 2019 Stephan Kulow <coolo@suse.com>
- updated to 8.16
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.16  2019-05-14
  - Improved Mojo::Headers to reject characters in header values that would
    corrupt the HTTP message.
  - Fixed getopt function in Mojo::Util to behave more like GetOptionsFromArray.
    (jberger, reneeb)
* Sat Apr 27 2019 Stephan Kulow <coolo@suse.com>
- updated to 8.15
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.15  2019-04-26
  - Updated jQuery to version 3.4.0.
  - Improved wait method in Mojo::Promise not to be affected by manually stopped
    event loops. (Grinnz)
  - Fixed a bug where the new method in Mojo::Promise could not be passed a
    callback to wrap continuation-passing style APIs, which is incompatible with
    the JavaScript API.
* Fri Apr 19 2019 Stephan Kulow <coolo@suse.com>
- updated to 8.14
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.14  2019-04-18
  - Added EXPERIMENTAL timer method to Mojo::Promise.
  - Added header_exists and header_exists_not methods to Test::Mojo.
  - Fixed a bug where the finally callback in Mojo::Promise was passed a value,
    which is incompatible with the JavaScript API.
  - Fixed a bug in Mojo::Promise where the finally method could change promise
    values.
  - Fixed a merge bug in Mojo::Parameters where multiple values sharing the same
    name could get lost.
* Fri Mar 22 2019 Stephan Kulow <coolo@suse.com>
- updated to 8.13
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.13  2019-03-21
  - Added EXPERIMENTAL map method to Mojo::Promise. (jberger)
  - Added EXPERIMENTAL min_compress_size attribute to Mojolicious::Renderer.
    (CandyAngel, mjemmeson)
  - Improved the security of signed cookies by also signing the cookie name.
    Note that this means that all sessions will be reset.
  - Fixed Mojo::IOLoop::Server to not check if listen sockets are writable.
* Sat Feb  2 2019 Stephan Kulow <coolo@suse.com>
- updated to 8.12
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.12  2019-01-27
  - Added EXPERIMENTAL timeout method to Mojo::Promise. (batman)
  - Removed deprecated module Mojolicious::Plugin::PODRenderer.
  - Removed deprecated method mojo_lib_dir from Mojo::Home.
  - Fixed rare warning in Mojo::Log. (Grinnz)
* Thu Jan  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 8.11
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.11  2019-01-01
  - Added EXPERIMENTAL support for SameSite cookies to better protect
    Mojolicious applications from CSRF attacks. (dylanwh, sri)
  - Added EXPERIMENTAL samesite attributes to Mojo::Cookie::Response and
    Mojolicious::Cookies. (dylanwh, sri)
  - Added lstat method to Mojo::File. (Grinnz)
  - Added remove method to Mojo::File.
  - Improved eval command with support for promises. (jberger)
  - Improved Mojo::JSON::Pointer to ignore many invalid JSON Pointers.
* Fri Dec 21 2018 Stephan Kulow <coolo@suse.com>
- updated to 8.10
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.10  2018-12-18
  - Added reset event to Mojo::IOLoop.
  - Added limit argument to split method in Mojo::ByteStream. (s1037989)
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 8.09
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.09  2018-12-02
  - Added touch method to Mojo::File.
  - Added max_depth option to list_tree method in Mojo::File.
  8.08  2018-11-26
  - Added stat method to Mojo::File.
  8.07  2018-11-16
  - Fixed a bug that caused debug log messages to be generated for static files.
  - Fixed a bug in Mojo::Server::Morbo that prevented the before_server_start
    hook from getting emitted.
* Fri Nov  9 2018 Stephan Kulow <coolo@suse.com>
- updated to 8.06
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.06  2018-11-07
  - Added support for progress updates to Mojo::IOLoop::Subprocess. (karjala)
  - Added progress method to Mojo::IOLoop::Subprocess. (karjala)
  - Added progress event to Mojo::IOLoop::Subprocess. (karjala)
  - Improved debug, error, fatal, info and warn methods in Mojo::Log to accept
    closures to generate log messages on demand. So expensive code for debugging
    can be deactivated easily in production.
  - Improved Mojo::Log to use the time format "2018-11-08 14:25:5.76027" and to
    include the process id in log messages.
  - Improved Mojolicious performance by up to 10%% with more efficient logging.
  - Fixed a problem with the built in templates where an image was missing.
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 8.05
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.05  2018-10-25
  - Deprecated Mojolicious::Plugin::PODRenderer in favor of alternatives from
    CPAN.
  - Deprecated Mojo::Home::mojo_lib_dir.
  - Replaced continue, flash, redirect_to, respond_to and validation methods in
    Mojolicious::Controller with helpers in Mojolicious::Plugin::DefaultHelpers.
  - Updated FAQ with a warning not to use Perl 5.10.x and 5.12.x with
    Mojolicious.
  8.04  2018-10-21
  - Added EXPERIMENTAL module Mojo::DynamicMethods. (mst)
  - Replaced all uses of AUTOLOAD with a much faster alternative, so helpers are
    faster by up to 400%% and stack traces contain more information. (mst)
  - Removed experimental status from server method in Mojolicious.
  8.03  2018-10-16
  - Added support for weak reference accessors to Mojo::Base. (mst)
  - Updated List::Util requirement to 1.41 for set_subname support.
  - Fixed a small bug in Mojo::UserAgent where request timeouts could be created
    twice.
  - Improved Mojo::Exception to include a stack trace in verbose output.
  - Improved Mojolicious::Types to use the correct MIME types for woff and
    woff2 files.
  8.02  2018-10-01
  - Deprecated Mojo::Transaction::success in favor of Mojo::Transaction::result
    and Mojo::Transaction::error. Unfortunately this method is used a lot in
    legacy code, so this deprecation will be in effect until the next major
    release.
  - Added support for gzip compression of dynamically generated responses
    (enable with $app->renderer->compress(1)).
  - Added EXPERIMENTAL compress attribute to Mojolicious::Renderer.
  - Added compressed attribute to Mojo::UserAgent::Transactor.
  - Added EXPERIMENTAL respond method to Mojolicious::Renderer.
  - Added save_to method to Mojo::Message.
  - Added gunzip and gzip methods to Mojo::ByteStream.
  - Added gunzip and gzip functions to Mojo::Util.
  - Improved HTML5.2 compliance of Mojo::DOM::HTML.
  - Fixed a bug in Mojo::Transaction::HTTP that prevented the finish event in
    Mojo::Message::Request from getting emitted sometimes.
  - Fixed a bug in Mojo::Promise where the ioloop attribute was not a weakened
    reference after object construction.
  - Fixed a bug where the is_fresh helper could only handle If-None-Match
    headers with a single etag value.
* Wed Sep 26 2018 Stephan Kulow <coolo@suse.com>
- updated to 8.01
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  8.01  2018-09-25
  - Updated jQuery to version 3.3.1.
  - Fixed order of command namespaces so Mojolicious can be upgraded without
    uninstalling first.
  - Fixed a small problem in one of the TLS tests where an error message check
    was too picky.
* Wed Sep 19 2018 Stephan Kulow <coolo@suse.com>
- updated to 8.0
  see /usr/share/doc/packages/perl-Mojolicious/Changes
* Sat Sep  1 2018 coolo@suse.com
- updated to 7.94
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.94  2018-08-27
  - Added EXPERIMENTAL content_type and file_type methods to Mojolicious::Types.
  - Fixed a bug where the reply->file helper would not try to set a Content-Type
    header.
  - Fixed a bug where the render method in Mojolicious::Controller would not
    always use Mojolicious::Types to find the correct Content-Type value.
* Tue Aug 14 2018 marius.kittler@suse.com
- Update to 7.93
  - See /usr/share/doc/packages/perl-Mojolicious/Changes
  - Most notable change is revert of streaming related changes
    causing instability (eg. some openQA internal tests were
    randomly failing).
* Sun Jul 22 2018 coolo@suse.com
- updated to 7.88
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.88  2018-07-11
  - Added EXPERIMENTAL bytes_read, bytes_written and transition methods to
    Mojo::IOLoop::Stream.
  - Added transition event to Mojo::IOLoop::Stream.
  - Improved default request ids generated by Mojo::Message::Request to be a
    little more unique.
  - Fixed a bug where prefork tests would fail if a prefork server was already
    running.
  7.87  2018-07-04
  - Added optional support for Cpanel::JSON::XS to Mojo::JSON for much better
    JSON encoding and decoding performance. That also means Mojo::JSON can no
    longer encode the two Unicode whitespace characters u2028 and u2029, since
    this is unsupported by Cpanel::JSON::XS.
  - Improved Mojo::JSON to encode unknown reference types to "null",
    consistently with Cpanel::JSON::XS.
  7.86  2018-07-02
  - Added template attribute to Mojolicious::Command.
  - Added spawn event to Mojo::IOLoop::Subprocess.
  - Improved Mojo::IOLoop::Subprocess to only fork new processes after the event
    loop has been started.
  7.85  2018-06-17
  - Removed deprecated build_tx, config, handler and log methods from Mojo.
  - Added promisify method to Mojo::UserAgent::Transactor.
  - Improved Mojolicious::Command to die on template errors.
  7.84  2018-06-05
  - Fixed a bug where test servers would be started when reusing a
    Mojo::UserAgent object after fork.
  7.83  2018-06-02
  - Replaced MOJO_DAEMON_DEBUG and MOJO_USERAGENT_DEBUG environment variables
    with MOJO_SERVER_DEBUG and MOJO_CLIENT_DEBUG. (anparker)
  - Updated IO::Socket::SSL requirement to 2.009 for ALPN support.
  - Added modules Mojo::IOLoop::Stream::HTTPClient,
    Mojo::IOLoop::Stream::HTTPServer, Mojo::IOLoop::Stream::WebSocketClient and
    Mojo::IOLoop::Stream::WebSocketServer. (anparker)
  - Added transition method to Mojo::IOLoop. (anparker)
  - Added close_connections method to Mojo::Server::Daemon. (anparker)
  - Added stream_class and tls_protocols arguments to client and server methods
    in Mojo::IOLoop. (anparker, sri)
  - Fixed a small render_maybe argument localization bug.
  7.82  2018-05-27
  - Removed experimental status from new_tag and selector methods in Mojo::DOM.
  - Improved Mojo::Server::PSGI with support for the before_server_start hook.
  - Fixed a bug where render_maybe in Mojolicious::Controller could not render
    multiple alternatives properly because arguments were not localized.
* Wed May 23 2018 coolo@suse.com
- updated to 7.81
  see /usr/share/doc/packages/perl-Mojolicious/Changes
* Sat May 19 2018 coolo@suse.com
- updated to 7.79
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.79  2018-05-14
  - Added EXPERIMENTAL selector method to Mojo::DOM.
  - Added reply->file helper to Mojolicious::Plugin::DefaultHelpers.
* Sat May 12 2018 coolo@suse.com
- updated to 7.78
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.78  2018-05-11
  - Deprecated delay helper in Mojolicious::Plugin::DefaultHelpers.
  - Added EXPERIMENTAL new_tag method to Mojo::DOM. (jberger, sri)
  - Added EXPERIMENTAL tag method to Mojo::DOM::HTML.
  - Added EXPERIMENTAL tag_to_html function to Mojo::DOM::HTML.
  - Improved performance of all DOM manipulation methods in Mojo::DOM
    significantly when reusing Mojo::DOM objects.
  - Fixed a Windows directory traversal security issue. (dmanto)
* Wed May  2 2018 coolo@suse.com
- updated to 7.77
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.77  2018-04-28
  - Added support for namespace selectors like "ns|*" to Mojo::DOM::CSS.
    (jberger)
  - Added support for :link and :visited pseudo-classes to Mojo::DOM::CSS.
  - Added support for hyphen-separated list attribute selectors like
    "[heflang|=en]" to Mojo::DOM::CSS.
* Wed Apr 25 2018 coolo@suse.com
- updated to 7.76
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.76  2018-04-23
  - Due to lack of domain experts on the team, Windows is no longer officially
    supported. Moving foward, we will try to keep Mojolicious installable on
    Windows, but cannot make any promises regarding security and/or reliability.
  - Fixed a bug in Mojolicious::Plugin::Config where the config stash value was
    not available when the config_override feature was used. (tim)
* Wed Apr 11 2018 coolo@suse.com
- updated to 7.75
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.75  2018-04-09
  - Deprecated placeholder quoting with "(placeholder)" in favor of
    "<placeholder>".
  - Fixed warnings in Mojo::Collection.
* Tue Apr 10 2018 coolo@suse.com
- updated to 7.74
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.74  2018-04-06
  - Improved unknown placeholder types to match nothing in
    Mojolicious::Routes::Pattern.
* Sat Apr  7 2018 coolo@suse.com
- updated to 7.73
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.73  2018-04-05
  - Added support for routes with placeholder types.
  - Added types attribute to Mojolicious::Routes and
    Mojolicious::Routes::Pattern.
  - Added add_type method to Mojolicious::Routes.
  - Added to_file method to Mojo::Asset, Mojo::Asset::File and
    Mojo::Asset::Memory.
  - Added num placeholder type to Mojolicious::Routes.
  - Removed deprecated use of Mojo::Promise::all and Mojo::Promise::race as
    instance methods.
* Tue Apr  3 2018 coolo@suse.com
- updated to 7.72
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.72  2018-04-02
  - Improved Mojo::Content::MultiPart performance for large numbers of parts.
    (philipspencer)
  - Fixed another problem with ordering of sources for content negotiation in
    Mojolicious::Renderer.
* Sat Mar 17 2018 coolo@suse.com
- updated to 7.71
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.71  2018-03-15
  - Deprecated Mojo::build_tx, Mojo::Config, Mojo::handler and Mojo::log.
  - Added config method to Mojolicious.
  - Fixed exceptions caused by non-UTF-8 files in Mojo::Exception. (Grinnz)
* Fri Mar  2 2018 coolo@suse.com
- updated to 7.70
  see /usr/share/doc/packages/perl-Mojolicious/Changes
* Sun Feb 25 2018 coolo@suse.com
- updated to 7.69
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.69  2018-02-24
  - Improved respond_to method in Mojolicious::Controller and accepts helper in
    Mojolicious::Plugin::DefaultHelpers to no longer limit support for multiple
    MIME types to requests containing an X-Requested-With header, since browsers
    have become smarter about requesting what they actually want.
* Sat Feb 24 2018 coolo@suse.com
- updated to 7.68
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.68  2018-02-22
  - Fixed RFC 7230 compliance bugs in Mojo::Message::Request that prevented
    "GET //foo/bar HTTP/1.1" to be interpreted as a request target in origin
    form.
* Wed Feb 21 2018 coolo@suse.com
- updated to 7.67
  see /usr/share/doc/packages/perl-Mojolicious/Changes
* Thu Feb 15 2018 coolo@suse.com
- updated to 7.66
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.66  2018-02-13
  - This release contains fixes for security issues, everybody should upgrade!
  - Removed origin attribute of Mojo::Cookie::Response.
  - Removed deprecated data and remaining methods from Mojo::IOLoop::Delay.
  - Added host_only attribute to Mojo::Cookie::Response.
  - Improved all method in Mojo::Promise to resolve with no results if no
    promises have been passed.
  - Fixed a bug in Mojo::UserAgent::CookieJar where old cookies could be leaked.
    (exp-innit, sri)
* Mon Feb 12 2018 coolo@suse.com
- updated to 7.65
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.65  2018-02-11
  - Added EXPERIMENTAL timing->begin, timing->elapsed, timing->rps and
    timing->server_timing helpers to Mojolicious::Plugin::DefaultHelpers.
  - Added EXPERIMENTAL server_timing method to Mojo::Headers.
  - Added support for new HTTP status code.
* Wed Feb  7 2018 coolo@suse.com
- updated to 7.64
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.64  2018-02-07
  - Fixed a bug in Mojo::Log where short log messages spanning multiple lines
    would not be formatted properly for systemd.
  7.63  2018-02-06
  - Improved Mojo::Log to use native systemd log levels.
  7.62  2018-02-01
  - Added -u option to get command. (jberger)
  - Added dont_use_nlink option to list_tree method in Mojo::File.
  - Added reverse proxy section to Mojolicious::Guides::Cookbook. (polettix)
  - Fixed a promise resolution bug in Mojo::Promise.
* Tue Jan 16 2018 coolo@suse.com
- updated to 7.61
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.61  2018-01-08
  - Increased default upgrade_timeout from 60 to 180 seconds in
    Mojo::Server::Hypnotoad.
* Thu Jan  4 2018 coolo@suse.com
- updated to 7.60
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.60  2018-01-02
  - Deprecated use of Mojo::Promise::all and Mojo::Promise::race as instance
    methods.
  - Improved all and race methods in Mojo::Promise to be able to handle
    arbitrary then-ables.
  - Improved number detection in Mojo::JSON with a workaround for an upcoming
    breaking change in Perl 5.28. (haarg)
  - Improved HTML Living Standard compliance of Mojo::DOM::HTML.
  - Fixed a bug in Mojo::Base that prevented composition of multiple roles.
    (aferreira, batman)
  - Fixed a bug in Mojolicious::Static where text files from DATA sections would
    not be UTF-8 encoded. (Grinnz)
* Mon Dec 18 2017 coolo@suse.com
- updated to 7.59
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.59  2017-12-15
  - Moved home and ua attributes from Mojo to Mojolicious.
  - Changed Mojo::IOLoop::Client to only start a thread pool with
    Net::DNS::Native on demand. (Grinnz)
  - Improved subprocess method in Mojo::IOLoop to allow for easier role
    composition.
  - Fixed RFC 7230 compliance bug in Mojo::Message::Response. (jberger)
* Mon Dec  4 2017 coolo@suse.com
- updated to 7.58
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.58  2017-12-02
  - Added websocket_p method to Mojo::UserAgent.
* Sun Nov 19 2017 coolo@suse.com
- updated to 7.57
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.57  2017-11-18
  - Fixed installation problems with some versions of Perl on Windows.
* Fri Nov 17 2017 coolo@suse.com
- updated to 7.56
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.56  2017-11-14
  - Added num check to Mojolicious::Validator.
  - Improved built-in templates with high resolution logos.
* Wed Nov  8 2017 coolo@suse.com
- updated to 7.55
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.55  2017-11-06
  - Added -role flag to Mojo::Base. (jberger)
  - Improved tablify function in Mojo::Util to work with non-rectangular arrays.
    (CandyAngel, jabberwok)
  - Improved Windows compatibility of Mojo::Server::Daemon.
* Sun Nov  5 2017 coolo@suse.com
- updated to 7.54
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.54  2017-11-05
  - Fixed a bug in Mojo::Promise where promise chains could not recover from
    rejections.
  7.53  2017-11-04
  - Added module Mojo::Promise.
  - Improved Mojo::IOLoop::Delay to be a subclass of Mojo::Promise.
* Fri Nov  3 2017 coolo@suse.com
- updated to 7.52
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.52  2017-11-02
  - Added delete_p, get_p, head_p, options_p, patch_p, post_p, put_p and start_p
    methods to Mojo::UserAgent.
* Thu Nov  2 2017 coolo@suse.com
- updated to 7.51
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.51  2017-10-31
  - Added -signatures flag to Mojo::Base and Mojolicious::Lite.
  - Added support for new HTTP status code.
  - Improved ojo to enable subroutine signatures automatically on Perl 5.20+.
* Tue Oct 31 2017 coolo@suse.com
- updated to 7.50
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.50  2017-10-30
  - Deprecated error and finish events in Mojo::IOLoop::Delay. Since there is no
    good way to warn our users about this deprecation, it will be in effect
    until the next major release. Where we will also change the base class from
    Mojo::EventEmitter to Mojo::Base.
  - Improved documentation browser with links to MetaCPAN.
  7.49  2017-10-28
  - Deprecated Mojo::IOLoop::Delay::data and Mojo::IOLoop::Delay::remaining.
  - Added Promises/A+ support. Note that Mojo::IOLoop::Delay previously
    inherited a catch method from Mojo::EventEmitter that was passed the error
    message as second argument instead of the first, so you might have to change
    $delay->catch(sub { my ($delay, $error) = @_; ... });
    to
    $delay->catch(sub { my ($error) = @_; ... });
  - Added all, catch, finally, race and then methods to Mojo::IOLoop::Delay.
  - Updated jQuery to version 3.2.1.
* Sun Oct 22 2017 coolo@suse.com
- updated to 7.48
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.48  2017-10-19
  - Reverted previous Mojo::File change since there were too many unintended
    side effects.
* Fri Oct 13 2017 coolo@suse.com
- updated to 7.47
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.47  2017-10-05
  - Added multipart content generator to Mojo::UserAgent::Transactor.
  - Fixed a bug in Mojo::File where parts of a path could get accidentally
    upgraded from bytes to characters.
* Wed Sep 13 2017 coolo@suse.com
- updated to 7.46
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.46  2017-09-12
  - Fixed support for versions of IO::Socket::SSL older than 1.965 again.
* Fri Sep  8 2017 coolo@suse.com
- updated to 7.45
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.45  2017-09-06
  - Fixed support for versions of IO::Socket::SSL older than 1.965. (mudler,
    foursixnine, genio, sri)
* Mon Sep  4 2017 coolo@suse.com
- updated to 7.44
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.44  2017-09-02
  - Reverted a previous change to Mojo::Loader that allowed for load_class to be
    called on the same class multiple times, since it had very bad side effects.
  - Improved Mojo::IOLoop::TLS to use a little less memory.
  - Fixed a bug where Mojolicious controllers like "MyApp::Controller::Foo::Bar"
    would disappear if loading the controller "MyApp::Controller::Foo" was
    attempted but failed.
* Sat Aug 19 2017 coolo@suse.com
- updated to 7.43
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.43  2017-08-18
  - Improved Mojo::Base role support with the ability to rebless objects.
* Fri Aug 18 2017 coolo@suse.com
- updated to 7.42
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.42  2017-08-17
  - Improved Mojo::Base role support with shorthands.
    MyClass->with_roles('MyClass::Role::Foo')
    becomes
    MyClass->with_roles('+Foo')
  7.41  2017-08-15
  - Added with_roles method to Mojo::ByteStream, Mojo::Collection, Mojo::DOM and
    Mojo::File.
* Tue Aug 15 2017 coolo@suse.com
- updated to 7.40
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.40  2017-08-14
  - Added support for Role::Tiny extensions to all classes based on Mojo::Base.
    (dotan)
  - Added with_roles method to Mojo::Base. (dotan)
  - Added the guide Mojolicious::Guides::Testing. (scottw)
  - Replaced systemd detection in Mojo::Log with the MOJO_LOG_SHORT environment
    variable, since there is no reliable way to detect systemd.
* Fri Aug  4 2017 coolo@suse.com
- updated to 7.39
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.39  2017-08-03
  - Removed experimental close_idle_connections method from
    Mojo::Server::Daemon.
  - Increased default graceful_timeout from 60 to 120 seconds in
    Mojo::Server::Prefork.
  - Improve Mojo::Server::Daemon to log request errors.
  - Fixed a bug where Mojo::Server::Daemon would close connections too quickly
    and interrupt requests.
* Wed Aug  2 2017 coolo@suse.com
- updated to 7.38
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.38  2017-07-30
  - Added extra attribute to Mojolicious::Static. (jabberwok)
  - Improve Mojo::URL performance significantly.
  - Fixed memory leak in Mojo::URL that was caused by a Perl 5.24 bug.
* Tue Jul 25 2017 coolo@suse.com
- updated to 7.37
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.37  2017-07-21
  - Added slugify method to Mojo::ByteStream. (Grinnz)
  - Added slugify function to Mojo::Util. (Grinnz)
  - Fixed bugs in Mojo::IOLoop and Mojo::Reactor::Poll that would prevent a
    reset from clearing events.
* Wed Jul 12 2017 coolo@suse.com
- updated to 7.36
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.36  2017-07-09
  - Fixed basename method in Mojo::File to work with relative paths. (jberger)
  - Fixed a bug where Mojo::Log could not correctly identify if it was deployed
    with systemd.
  - Fixed Mojo::HelloWorld to actually be a Mojolicious subclass.
  7.35  2017-07-05
  - Removed deprecated watch attribute from Mojo::Server::Morbo.
  - Added spare attribute to Mojo::Server::Prefork.
  - Added -s option to prefork command.
  - Added fd option to Mojo::IOLoop::Server::listen.
  - Added fd parameter to Mojo::Server::Daemon::listen.
  - Added spare setting to Hypnotoad.
  - Increased default graceful_timeout from 20 to 60 seconds and
    heartbeat_timeout from 20 to 30 seconds in Mojo::Server::Prefork.
* Tue Jul  4 2017 coolo@suse.com
- updated to 7.34
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.34  2017-07-02
  - Added short attribute to Mojo::Log.
  - Improved Mojo::Log to print log messages without timestamps to STDERR when
    deployed with systemd.
  - Improved Mojo::DOM performance slightly.
* Fri Jun  9 2017 coolo@suse.com
- updated to 7.33
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.33  2017-06-05
  - Added EXPERIMENTAL support for :matches pseudo-class and :not pseudo-class
    with compount selectors to Mojo::DOM::CSS.
  - Fixed a few form element value extraction bugs in Mojo::DOM.
  - Fixed version command to use the new MetaCPAN API, since the old one got
    shut down.
* Wed May 31 2017 coolo@suse.com
- updated to 7.32
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.32  2017-05-28
  - Added -f option to get command.
  - Improved get command with support for passing request data by redirecting
    STDIN.
  - Fixed memory leak in Mojo::IOLoop::Client that sometimes prevented the
    connect timeout from working correctly for TLS handshakes.
* Tue Apr 25 2017 coolo@suse.com
- updated to 7.31
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.31  2017-04-23
  - Removed deprecated files, slurp and spurt functions from Mojo::Util.
  - Removed deprecated parts attribute from Mojo::Home.
  - Removed deprecated slurp and spurt methods from Mojo::ByteStream.
  - Removed deprecated lib_dir, list_files, parse and rel_dir methods from
    Mojo::Home.
  - Removed deprecated rel_dir method from Mojolicious::Command.
  - Removed deprecated is_status_class method from Mojo::Message::Response.
  - Fixed a bug in the app generator command where the config file name was not
    based on the application moniker.
* Fri Apr  7 2017 coolo@suse.com
- updated to 7.30
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.30  2017-04-04
  - Deprecated Mojo::Server::Morbo::watch in favor of
    Mojo::Server::Morbo::Backend::Poll::watch. (marcus)
  - Added support for pluggable Morbo backends. (marcus)
  - Added Mojo::Server::Morbo::Backend and Mojo::Server::Morbo::Backend::Poll
    modules. (marcus)
  - Added backend attribute to Mojo::Server::Morbo. (marcus)
  - Added -b option to Morbo. (marcus)
* Wed Mar 15 2017 coolo@suse.com
- updated to 7.29
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.29  2017-03-12
  - Added support for overriding configuration files in applications tested with
    Test::Mojo.
  - Added html_attr_unescape function to Mojo::Util.
  - Fixed unescaping of HTML5 attribute values in Mojo::DOM::HTML.
* Wed Mar  8 2017 coolo@suse.com
- updated to 7.28
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.28  2017-03-07
  - Added copy_to, realpath and sibling methods to Mojo::File.
  - Added dir option to list_tree method in Mojo::File.
  - Improved app generator command to generate a config file.
    (tudorconstantin)
* Tue Feb 28 2017 coolo@suse.com
- updated to 7.27
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.27  2017-02-27
  - Added support for UNIX domain sockets. (sri, salva)
  - Improved Mojo::UserAgent to complain about unsupported protocols.
  - Fixed a bug in Mojo::URL where invalid host strings could be generated.
  - Fixed blib handling in Mojo::Home.
* Fri Feb 17 2017 coolo@suse.com
- updated to 7.26
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.26  2017-02-15
  - Fixed bug in Mojo::IOLoop::Subprocess where starting multiple subprocesses
    at once could cause expcetions. (jberger)
* Mon Feb 13 2017 coolo@suse.com
- updated to 7.25
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.25  2017-02-09
  - Fixed cleanup bugs in Mojo::IOLoop::Stream.
* Wed Feb  8 2017 coolo@suse.com
- updated to 7.24
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.24  2017-02-05
  - Added open method to Mojo::File.
  - Added tempfile function to Mojo::File.
  - Fixed bug in Mojo::Asset::File where the slurp method would not work
    correctly for very large files.
* Mon Jan 30 2017 coolo@suse.com
- updated to 7.23
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.23  2017-01-29
  - Added max_request_size attribute to Mojolicious.
  - Added max_response_size attribute to Mojo::UserAgent.
  - Added to_unsafe_string method to Mojo::URL.
  - Added -S option to get command.
  - Fixed a data corruption problem in Mojo::IOLoop::Stream, caused by a
    dependency of IO::Socket::SSL on the internal representation of strings,
    which differs from IO::Socket::IP. (coolo, sri)
* Fri Jan 27 2017 coolo@suse.com
- updated to 7.22
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.22  2017-01-25
  - Added ports method to Mojo::Server::Daemon.
  - Added remove_tree method to Mojo::File.
  - Improved spurt method in Mojo::File with support for writing multiple chunks
    at once.
* Mon Jan 23 2017 coolo@suse.com
- updated to 7.21
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.21  2017-01-21
  - Added extract_usage function to Mojo::Util.
  - Improve getopt function in Mojo::Util to use @ARGV by default.
* Wed Jan 18 2017 coolo@suse.com
- updated to 7.20
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.20  2017-01-18
  - Fixed a bug in Mojo::File where the make_path method would die even if no
    error occurred.
  - Fixed warnings in Mojo::IOLoop::TLS.
* Mon Jan 16 2017 coolo@suse.com
- updated to 7.19
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.19  2017-01-14
  - Added module Mojo::IOLoop::TLS.
  - Added can_nnr and can_socks methods to Mojo::IOLoop::Client.
* Thu Jan 12 2017 coolo@suse.com
- updated to 7.18
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.18  2017-01-11
  - Fixed support for relative %%INC paths in Mojo::Home.
  - Fixed a bug in Mojo::URL where invalid fragment strings could be generated.
* Wed Jan 11 2017 coolo@suse.com
- updated to 7.17
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.17  2017-01-11
  - Fixed Windows bugs in Mojo::File. (kmx)
  7.16  2017-01-10
  - Fixed Windows bugs in Mojo::File. (kmx)
  7.15  2017-01-09
  - Deprecated Mojo::ByteStream::slurp and Mojo::Util::slurp in favor of
    Mojo::File::slurp.
  - Deprecated Mojo::ByteStream::spurt and Mojo::Util::spurt in favor of
    Mojo::File::spurt.
  - Deprecated Mojo::Util::files in favor of Mojo::File::list_tree.
  - Deprecated Mojo::Home::lib_dir, Mojo::Home::parse, Mojo::Home::parts in
    favor of new features inherited from the Mojo::File base class.
  - Added module Mojo::File.
  - Improved Mojo::Home to be a subclass of Mojo::File.
  - Improved mojo_lib_dir and rel_file methods in Mojo::Home to return
    Mojo::Home objects.
  - Improved rel_file methods in Mojolicious::Command to return Mojo::File
    objects.
  - Improved every_param and param methods in Mojolicious::Validator::Validation
    to use the current topic.
* Fri Jan  6 2017 coolo@suse.com
- updated to 7.14
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.14  2017-01-04
  - Deprecated Mojo::Home::list_files in favor of Mojo::Util::files.
  - Deprecated Mojo::Home::rel_dir in favor of Mojo::Home::rel_file.
  - Deprecated Mojolicious::Command::rel_dir in favor of
    Mojolicious::Command::rel_file.
  - Fixed a bug in Mojo::IOLoop::Subprocess where the pipe used for IPC could
    disappear because of a timeout.
* Fri Dec 30 2016 coolo@suse.com
- updated to 7.13
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.13  2016-12-23
  - Deprecated Mojo::Message::Response::is_status_class in favor of new is_*
    methods.
  - Added result method to Mojo::Transaction.
  - Added is_client_error, is_error, is_info, is_redirect, is_server_error and
    is_success methods to Mojo::Message::Response.
  - Fixed bug where Morbo could not handle broken symlinks. (Grinnz)
* Wed Dec 21 2016 coolo@suse.com
- updated to 7.12
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.12  2016-12-18
  - Added button_to and csrf_button_to helpers to
    Mojolicious::Plugin::TagHelpers.
  - Removed experimental status from Mojo::IOLoop::Subprocess.
  - Removed experimental status from subprocess method in Mojo::IOLoop.
* Thu Dec  1 2016 coolo@suse.com
- updated to 7.11
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.11  2016-11-30
  - Added EXPERIMENTAL close_idle_connections method to Mojo::Server::Daemon.
  - Improved one_tick method in Mojo::IOLoop to protect from recursion, similar
    to the start method.
  - Improved log attribute in Mojolicious to make it easier to override default
    settings. (jberger)
  - Fixed bug in Mojo::Server::Prefork where workers would accept keep-alive
    requests after a graceful shutdown had already been initiated.
  - Fixed bugs in Mojo::Util and Mojo::Asset::File where incomplete writes would
    not be recognized as errors. (bobkare, sri)
* Wed Nov  2 2016 coolo@suse.com
- updated to 7.10
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.10  2016-11-01
  - Added getopt function to Mojo::Util.
* Mon Oct 24 2016 coolo@suse.com
- updated to 7.09
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.09  2016-10-22
  - Added every_header method to Mojo::Headers.
  - Fixed redirect bug in Mojo::UserAgent::Transactor.
  - Fixed a few proxy bugs in Mojo::UserAgent.
* Tue Sep 27 2016 coolo@suse.com
- updated to 7.08
  see /usr/share/doc/packages/perl-Mojolicious/Changes
* Mon Sep 26 2016 coolo@suse.com
- updated to 7.08
  see /usr/share/doc/packages/perl-Mojolicious/Changes
* Sun Sep 25 2016 coolo@suse.com
- updated to 7.08
  see /usr/share/doc/packages/perl-Mojolicious/Changes
* Sat Sep 24 2016 coolo@suse.com
- updated to 7.08
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.08  2016-09-23
  - Added -i and -o options to get command.
  - Updated jQuery to version 3.1.1.
  - Improved accuracy of finished_ok test in Test::Mojo.
  - Fixed state transition bug in Mojo::Transaction::HTTP that caused message
    bodies to be included in responses to HEAD requests.
* Wed Sep 21 2016 coolo@suse.com
- updated to 7.07
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.07  2016-09-20
  - Fixed bug in Mojo::UserAgent::Transactor where 303 redirects would not be
    followed correctly with GET requests. (jberger)
* Sun Sep 18 2016 coolo@suse.com
- updated to 7.06
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.06  2016-09-17
  - Fixed bug where Mojolicious::Renderer would wrap text in layouts.
  - Fixed a few test description encoding bugs in Test::Mojo.
* Wed Aug 31 2016 coolo@suse.com
- updated to 7.05
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.05  2016-08-29
  - Fixed bug in Mojo::IOLoop::Subprocess where EV would steal the subprocess
    exit status.
  7.04  2016-08-28
  - Added EXPERIMENTAL support for performing computationally expensive
    operations in subprocesses, without blocking the event loop. (jberger, sri)
  - Added EXPERIMENTAL module Mojo::IOLoop::Subprocess. (jberger, sri)
  - Added EXPERIMENTAL subprocess method to Mojo::IOLoop. (jberger, sri)
  - Improved many methods in Mojolicious::Controller to die more gracefully if
    the connection has already been closed.
  - Fixed bug where Mojo::UserAgent would try to follow redirects for CONNECT
    requests.
* Thu Aug 18 2016 coolo@suse.com
- updated to 7.03
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.03  2016-08-17
  - Fixed packaging errors.
  7.02  2016-08-17
  - Fixed bugs in Mojo::Loader and Mojo::Util where the DATA handle would be
    mentioned in error messages. (jberger, kiwiroy, sri)
* Tue Aug  2 2016 coolo@suse.com
- updated to 7.01
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.01  2016-08-01
  - Improved support for systemd.
  - Fixed a bug in Mojo::Server::Prefork where PID files would not contain a
    newline character.
* Tue Jul 19 2016 coolo@suse.com
- updated to 7.0
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  7.0  2016-07-19
  - Code name "Doughnut", this is a major release.
  - Removed Mojolicious::Plugin::Charset.
  - Removed authority method from Mojo::URL.
  - Removed squish method from Mojo::ByteStream.
  - Removed squish function from Mojo::Util.
  - Removed support for smart whitespace trimming from all_text and text methods
    in Mojo::DOM.
  - Updated jQuery to version 3.1.0.
  - Improved Mojo::URL not to include the userinfo part when generating URLs, as
    recommended by the URL Living Standard.
  - Improved Mojolicious::Plugin::Config to no longer log which files have been
    loaded.
  - Fixed trailing slash bug in Mojo::URL.
  - Fixed a few whitespace bugs in Mojo::DOM.
  - Fixed attribute selector bug in Mojo::DOM::CSS. (Akron)
  - Fixed a bug causing headers with zero length values to be ignored by the get
    command. (jberger)
* Thu Jun 23 2016 coolo@suse.com
- updated to 6.66
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.66  2016-06-16
  - Fixed support for CONNECT requests without keep alive connections in
    Mojo::UserAgent. (anparker, sri)
  6.65  2016-06-14
  - Added password and username methods to Mojo::URL.
  - Updated jQuery to version 3.0.0.
  - Fixed "0" value bug in Mojo::UserAgent::CookieJar. (jamadam)
* Sun Jun 12 2016 coolo@suse.com
- updated to 6.64
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.64  2016-06-09
  - Updated HTML5 entities in Mojo::Util.
  - Improved Mojo::IOLoop to fall back to Mojo::Reactor::Poll if Perl has been
    compiled with fork emulation.
  6.63  2016-06-03
  - Removed deprecated check method from Mojo::Server::Morbo.
  - Removed deprecated build, compile and interpret methods from Mojo::Template.
  - Removed deprecated multi_accept methods from Mojo::IOLoop,
    Mojo::IOLoop::Server and Mojo::Server::Daemon.
  - Updated jQuery to version 2.2.4.
  - Improved generator commands not to overwrite existing files.
* Mon May 23 2016 coolo@suse.com
- updated to 6.62
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.62  2016-05-14
  - Removed deprecated is_debug, is_error, is_info and is_warn methods from
    Mojo::Log.
  - Improved support for Ubuntu on Windows.
* Thu May  5 2016 coolo@suse.com
- updated to 6.61
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.61  2016-04-30
  - Improved Mojo::Server::Daemon to no longer log when a connection has been
    closed prematurely.
  - Fixed bug in Mojo::Content where the drain event would not always be emitted
    for dynamically generated content with a Content-Length header.
  6.60  2016-04-25
  - Fixed bug in Mojo::IOLoop where stopping gracefully would sometimes result
    in connections getting closed too early. (anparker, sri)
  6.59  2016-04-22
  - Removed deprecated xss_escape function from Mojo::Util.
  - Improved HTML Living Standard compliance of Mojo::DOM::HTML.
  - Improved Mojo::Server::Daemon to log when a connection has been closed
    prematurely.
  - Improved Mojo::Server::Prefork to log when the manager process has been
    stopped.
  - Fixed a few tests to keep up with breaking changes in IO::Socket::SSL.
  - Fixed a few timing bugs in tests.
* Mon Apr 11 2016 coolo@suse.com
- updated to 6.58
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.58  2016-04-09
  - Removed deprecated build_frame and parse_frame methods from
    Mojo::Transaction::WebSocket.
  - Added fork policy to Mojolicious::Guides::Contributing.
  - Improved Mojo::JSON to generate canonical JSON objects.
  - Fixed bug in Mojo::Loader where classes with exceptions could not be loaded
    twice. (kiwiroy, sri)
* Mon Apr  4 2016 coolo@suse.com
- updated to 6.57
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.57  2016-03-23
  - Fixed a few validation bugs in Mojolicious::Validator::Validation.
    (Mikey, sri)
  - Fixed copyright notice.
  6.56  2016-03-16
  - Added hidden option to list_files method in Mojo::Home. (batman, sri)
  - Added hidden option to files function in Mojo::Util. (batman, sri)
  - Fixed bug where Morbo would not ignore hidden files. (batman, sri)
  - Fixed bug where Morbo would ignore the --verbose option.
  - Fixed keep-alive bug in Mojo::UserAgent. (jberger)
* Fri Mar 11 2016 coolo@suse.com
- updated to 6.55
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.55  2016-03-08
  - Deprecated Mojo::Server::Morbo::check in favor of
    Mojo::Server::Morbo::modified_files. (leejo, nugged)
  - Added modified_files method to Mojo::Server::Morbo. (leejo, nugged)
  - Improved renderer performance slightly.
  - Fixed a bug where Morbo would restart more than once if multiple files
    changed at the same time. (leejo, nugged)
* Tue Mar  8 2016 coolo@suse.com
- updated to 6.54
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.54  2016-03-06
  - Deprecated Mojo::Template::interpret in favor of Mojo::Template::process.
  - Deprecated Mojo::Template::build.
  - Deprecated Mojo::Template::compile.
  - Added support for named variables to Mojo::Template.
  - Added vars attribute to Mojo::Template.
  - Added process method to Mojo::Template.
  - Improved Mojo::Template performance slightly.
* Mon Mar  7 2016 coolo@suse.com
- updated to 6.53
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.53  2016-03-03
  - Removed multi_accept setting from Hypnotoad.
  - Removed -M options from daemon and prefork commands.
  - Deprecated Mojo::IOLoop::multi_accept.
  - Deprecated Mojo::IOLoop::Server::multi_accept.
  - Deprecated Mojo::Server::Daemon::multi_accept.
  - Added single_accept option to Mojo::IOLoop::Server::listen.
  - Added single_accept parameter to Mojo::Server::Daemon::listen.
  - Increased default max_requests from 25 to 100 in Mojo::Server::Daemon.
  - Increased default accepts from 1000 to 10000 in Mojo::Server::Prefork.
  - Improved performance of many Mojo::Util functions slightly.
  - Fixed default value bug in val method of Mojo::DOM.
  6.52  2016-03-02
  - Added is_accepting method to Mojo::IOLoop::Server.
  - Added -M option to daemon command.
  - Improved responsiveness of stop_gracefully method in Mojo::IOLoop.
  - Fixed bug in Mojo::IOLoop where too many connections could be accepted.
  - Fixed a few concurrency bugs in Mojo::IOLoop.
  6.51  2016-02-29
  - Fixed bug in Mojolicious::Plugin::EPLRenderer where empty templates from the
    DATA section would be ignored.
  - Fixed a few "0" value bugs in Mojolicious::Renderer.
  6.50  2016-02-27
  - Added throw method to Mojo::Exception.
  6.49  2016-02-26
  - Removed throw method from Mojo::Exception.
  - Added inspect method to Mojo::Exception.
  - Improved check_box and radio_button helpers with support for "on" default
    values.
  - Improved val method in Mojo::DOM with support for "on" default values.
  - Fixed url_for bug where routes with custom names would not match in the same
    order as routes with automatically generated names.
  - Fixed bug in Mojo::Template where not all exceptions were verbose.
  - Fixed Windows bug in "util.t".
  6.48  2016-02-24
  - Added files function to Mojo::Util.
  - Updated jQuery to version 2.2.1.
  - Improved url_for performance significantly.
  - Fixed bug where the results of the list_files method in Mojo::Home would
    include directories.
  - Fixed a few small CGI bugs.
* Sun Feb 21 2016 coolo@suse.com
- updated to 6.47
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.47  2016-02-19
  - Deprecated Mojo::Log::is_debug, Mojo::Log::is_error, Mojo::Log::is_info and
    Mojo::Log::is_warn in favor of Mojo::Log::is_level.
  - Added is_level method to Mojo::Log.
  - Fixed datetime_field helper to use the correct type attribute value.
* Mon Feb 15 2016 coolo@suse.com
- updated to 6.46
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.46  2016-02-13
  - Improved Mojo::Headers performance. (batman)
  - Fixed small proxy bug in Mojo::UserAgent::Transactor.
* Sat Feb 13 2016 coolo@suse.com
- updated to 6.45
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.45  2016-02-09
  - Deprecated Mojo::Util::xss_escape in favor of Mojo::Util::xml_escape.
  - Improved Mojo::Template performance slightly.
* Sun Feb  7 2016 coolo@suse.com
- updated to 6.44
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.44  2016-02-04
  - Removed deprecated format_regex attribute from Mojolicious::Routes::Pattern.
  - Improved get command not to use the user agent of the application.
  - Improved Mojo::JSON performance slightly.
  6.43  2016-02-01
  - Removed client_close and server_close methods from Mojo::Transaction.
  - Added closed method to Mojo::Transaction.
  - Added parse_message method to Mojo::Transaction::WebSocket.
  - Improved a few examples to avoid timing attacks.
  - Fixed timing bug in Mojo::Server::Daemon.
* Mon Jan 25 2016 coolo@suse.com
- updated to 6.42
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.42  2016-01-24
  - Fixed use of deprecated Perl feature in Mojo::JSON.
  - Fixed validation filter bugs in Mojolicious::Validator::Validation.
  6.41  2016-01-20
  - Added support for validation filters.
  - Added filters attribute to Mojolicious::Validator.
  - Added add_filter method to Mojolicious::Validator.
  - Added filter arguments to optional and required methods in
    Mojolicious::Validator::Validation.
  - Fixed MOJO_WEBSOCKET_DEBUG environment variable. (jberger)
* Tue Jan 19 2016 coolo@suse.com
- updated to 6.40
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.40  2016-01-13
  - Removed client_challenge, client_handshake, server_handshake and server_open
    methods from Mojo::Transaction::WebSocket. (batman, sri)
  - Removed is_writing method from Mojo::Transaction.
  - Removed upgrade event from Mojo::Transaction::HTTP.
  - Deprecated Mojo::Transaction::WebSocket::build_frame and
    Mojo::Transaction::WebSocket::parse_frame in favor of
    Mojo::WebSocket::build_frame and Mojo::WebSocket::parse_frame. (batman)
  - Replaced deprecated proxy method in Mojo::Message::Request with an
    attribute.
  - Added SNI support to all built-in web servers. (bpmedley, sri)
  - Added module Mojo::WebSocket. (batman)
  - Added established attribute to Mojo::Transaction::WebSocket.
  - Added completed method to Mojo::Transaction.
  - Updated jQuery to version 2.2.0.
  - Improved performance of Mojo::Server::Daemon and Mojo::UserAgent slightly.
  - Improved mtime attribute in Mojo::Asset::Memory to default to the value of
    $^T.
  - Improved app generator command to generate more portable scripts.
  - Fixed a few timing bugs.
  - Fixed url_for to handle fragments correctly.
* Wed Jan 13 2016 coolo@suse.com
- updated to 6.39
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.39  2016-01-03
  - Updated links to Mojolicious website.
  - Fixed small html_unescape bug in Mojo::Util.
  - Fixed handling of invalid max age in Mojo::UserAgent::CookieJar.
* Sat Dec 26 2015 coolo@suse.com
- updated to 6.38
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.38  2015-12-19
  - Updated prettify.js to version 8-Dec-2015.
  - Improved form generation in Mojo::UserAgent::Transactor to use UTF-8 as the
    default charset.
* Tue Dec 15 2015 coolo@suse.com
- updated to 6.37
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.37  2015-12-14
  - Added protocol and with_protocols methods to Mojo::Transaction::WebSocket.
  - Fixed a few reference encoding bugs in Mojo::JSON.
  - Fixed a few form generation bugs in Mojo::UserAgent::Transactor.
* Wed Dec  9 2015 coolo@suse.com
- updated to 6.36
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.36  2015-12-08
  - Improved Mojo::JSON performance slightly. (haarg)
  - Improved inactivity_timeout helper to return the current controller object.
* Sat Dec  5 2015 coolo@suse.com
- updated to 6.35
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.35  2015-12-04
  - Removed deprecated collecting method from Mojo::UserAgent::CookieJar.
  - Fixed warnings in Mojo::Cookie::Response.
* Wed Dec  2 2015 coolo@suse.com
- updated to 6.34
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.34  2015-12-01
  - Improved Hypnotoad to report problems that have occured during the creation
    of listen sockets.
  - Fixed bug in Mojo::DOM where the wrap method would attempt to wrap an
    HTML/XML fragment around the content of root nodes.
  - Fixed bug in Mojo::DOM where the wrap_content method would attempt to wrap
    an HTML/XML fragment around nodes that do not have children.
  - Fixed a few small formatting bugs in Mojolicious::Plugin::PODRenderer.
* Sat Nov 28 2015 coolo@suse.com
- updated to 6.33
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.33  2015-11-22
  - Updated IO::Socket::IP requirement to 0.37 for certain bug fixes.
  - Improved renderer not to require a return value from handlers.
  - Improved helper method in Mojolicious to replace already existing helpers
    silently.
* Fri Nov 20 2015 coolo@suse.com
- updated to 6.32
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.32  2015-11-18
  - Deprecated Mojolicious::Routes::Pattern::format_regex.
  - Added support for new HTTP status code.
  - Improved router performance.
  - Improved Mojo::DOM::CSS performance slightly. (jamadam)
  - Fixed a few case-sensitivity and An+B notation bugs in Mojo::DOM::CSS.
    (jamadam)
* Sun Nov 15 2015 coolo@suse.com
- updated to 6.31
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.31  2015-11-13
  - Improved documentation browser CSS.
  - Fixed handling of invalid URLs in Mojo::UserAgent::CookieJar.
  - Fixed a few small selector bugs in Mojo::DOM::CSS.
  - Fixed a few small formatting bugs in Mojolicious::Plugin::PODRenderer.
* Sat Nov 14 2015 coolo@suse.com
- updated to 6.30
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.30  2015-11-11
  - Fixed bug in Mojolicious::Renderer where layouts could not be used with
    template inheritance. (nic, sri)
* Sun Nov  8 2015 coolo@suse.com
- updated to 6.29
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.29  2015-11-03
  - Fixed a few bugs in built-in templates. (Zoffix, sri)
* Tue Nov  3 2015 coolo@suse.com
- updated to 6.28
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.28  2015-11-02
  - Improved build_app method in Mojo::Server to work more like the load_app
    method.
  - Fixed multi-line attribute bug in Mojo::DOM::HTML. (jamadam)
* Sat Oct 31 2015 coolo@suse.com
- updated to 6.27
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.27  2015-10-29
  - Updated HTML5 entities in Mojo::Util.
  - Improved Mojo::Server::Prefork to log if the process id file could not be
    created.
* Thu Oct 29 2015 coolo@suse.com
- updated to 6.26
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.26  2015-10-28
  - Renamed built-in templates with more descriptive names.
  - Added warmup method to Mojolicious::Renderer and Mojolicious::Static.
* Thu Oct 22 2015 coolo@suse.com
- updated to 6.25
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.25  2015-10-21
  - Deprecated Mojo::Message::Request::proxy with boolean and string arguments
    in favor of Mojo::Message::Request::via_proxy.
  - Replaced proxy method in Mojo::Message::Request with an attribute.
  - Moved all bundled files into "resources" directories.
  - Added via_proxy attribute to Mojo::Message::Request.
  - Improved Mojo::DOM::CSS to support selectors with leading and trailing
    whitespace.
  - Improved rendering of built-in templates to show actual template names in
    log messages.
  - Fixed punycode bug in Mojo::URL.
  - Fixed "0" value bug in Mojo::JSON::Pointer.
* Fri Oct 16 2015 coolo@suse.com
- updated to 6.24
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.24  2015-10-13
  - Improved session security by not storing secrets in the stash and making
    CSRF tokens much harder to guess.
  - Improved commands to show all options that can affect their behavior.
  - Fixed bug in Mojo::JSON::Pointer that prevented JSON Pointers with trailing
    slash from working correctly. (dolmen)
  - Fixed support for domains with trailing dot in Mojo::URL.
* Sat Oct 10 2015 coolo@suse.com
- updated to 6.23
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.23  2015-10-06
  - Improved documentation browser CSS.
  - Fixed bug in Mojo::Transaction::WebSocket where an unsupported protocol
    could be selected automatically.
  - Fixed input record separator bug in Mojo::Util. (Zoffix, sri)
  - Fixed small redirect bug in Mojo::UserAgent::Transactor.
* Sun Sep 27 2015 coolo@suse.com
- updated to 6.22
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.22  2015-09-26
  - Improved Mojo::JSON by reusing JSON::PP boolean constants.
  - Improved uniq method in Mojo::Collection to accept a callback. (CandyAngel)
  - Improved first and grep methods in Mojo::Collection to be able to call
    methods.
  - Improved support for empty attributes in Mojo::DOM::HTML.
* Wed Sep 23 2015 coolo@suse.com
- updated to 6.21
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.21  2015-09-23
  - Added val method to Mojo::DOM.
* Sun Sep 20 2015 coolo@suse.com
- updated to 6.20
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.20  2015-09-15
  - Deprecated Mojo::UserAgent::CookieJar::collecting in favor of
    Mojo::UserAgent::CookieJar::ignore.
  - Improved support for epoll/kqueue in Mojo::IOLoop::Client.
* Mon Sep 14 2015 coolo@suse.com
- updated to 6.19
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.19  2015-09-12
  - Added code of conduct to Mojolicious::Guides::Contributing.
  - Added ignore attribute to Mojo::UserAgent::CookieJar.
  - Added tls_version option to Mojo::IOLoop::Server::listen.
  - Added version parameter to Mojo::Server::Daemon::listen.
* Thu Sep  3 2015 coolo@suse.com
- updated to 6.18
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.18  2015-09-02
  - Improved portability of slurp function in Mojo::Util.
  - Fixed handling of parameters with multiple values in
    Mojolicious::Plugin::TagHelpers.
  - Fixed Makefile.PL to be compliant with version 2 of the CPAN distribution
    metadata specification. (Grinnz)
* Sun Aug 23 2015 coolo@suse.com
- updated to 6.17
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.17  2015-08-21
  - Improved slurp method in Mojo::Asset::File to only use one file descriptor.
  6.16  2015-08-19
  - Improved check_box, radio_button and select_field tag helpers to handle the
    attributes "checked" and "selected" correctly.
  - Improved performance of slurp function in Mojo::Util slightly.
* Wed Aug 19 2015 coolo@suse.com
- updated to 6.15
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.15  2015-08-13
  - Removed deprecated build_body and build_headers methods from Mojo::Content.
  - Improved Mojo::Transaction::HTTP performance slightly.
  - Fixed warnings in Mojo::DOM.
* Tue Jul 14 2015 coolo@suse.com
- updated to 6.14
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.14  2015-07-12
  - Improved app generator command not to create a log directory.
* Sun Jul 12 2015 coolo@suse.com
- updated to 6.13
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.13  2015-07-08
  - Added support for validating file uploads.
  - Added upload check to Mojolicious::Validator.
  - Improved error messages for broken applications in Mojo::Server. (mst)
  - Improved subscribers method in Mojo::EventEmitter to allow subscribers to be
    modified more easily.
* Sun Jun 21 2015 coolo@suse.com
- updated to 6.12
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.12  2015-06-18
  - Welcome to the Mojolicious core team Dan Book.
  - Added TO_JSON method to Mojo::Collection. (wttw)
  - Added find_packages function to Mojo::Loader.
  - Fixed bug in Mojo::Message where multipart content would get downgraded
    unnecessarily.
* Sun May 17 2015 coolo@suse.com
- updated to 6.11
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.11  2015-05-16
  - Deprecated build_body and build_headers methods in Mojo::Content.
  - Added headers_contain method to Mojo::Content.
  - Updated jQuery to version 2.1.4.
  - Fixed indentation of ASCII art in documentation browser. (jberger)
  - Fixed bug where inline was not considered a reserved stash value.
* Mon Apr 27 2015 coolo@suse.com
- updated to 6.10
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.10  2015-04-26
  - Removed support for user/group switching, because it never worked
    correctly, which means that this security feature has become an attack
    vector itself. If you depend on this functionality, you can now use the
    CPAN module Mojolicious::Plugin::SetUserGroup instead.
  - Removed group and user attributes from Mojo::Server.
  - Removed setuidgid method from Mojo::Server.
  - Removed group and user settings from Hypnotoad.
  - Removed -g/--group and -u/--user options from daemon and prefork commands.
  - Added next_tick method to Mojo::Reactor::Poll.
  - Improved next_tick callbacks to run in the same order in which they were
    registered.
* Sun Apr 26 2015 coolo@suse.com
- updated to 6.09
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.09  2015-04-25
  - Improved HTML Living Standard compliance of Mojo::Parameters. (riche, sri)
  - Fixed bug in Mojolicious::Types where the json MIME type did not specify a
    charset. (kaktus)
* Tue Apr 14 2015 coolo@suse.com
- updated to 6.08
  see /usr/share/doc/packages/perl-Mojolicious/Changes
  6.08  2015-04-09
  - Added is_established and server_open methods to
    Mojo::Transaction::WebSocket.
  - Improved finish and send methods in Mojolicious::Controller to
    automatically establish the WebSocket connection if necessary.
  - Improved pod_to_html helper in Mojolicious::Plugin::PODRenderer to unindent
    verbatim blocks. (OlegG)
  6.07  2015-04-07
  - Fixed Windows bug in "daemon.t".
  6.06  2015-04-06
  - Added element_count_is method to Test::Mojo. (Zoffix)
  - Added "chat.pl" to example scripts.
  - Improved Mojo::DOM::CSS to handle attribute selectors with single quotes
    correctly.
  6.05  2015-03-24
  - Fixed circular require bug in Mojo::Base and Mojo::Util.
  6.04  2015-03-23
  - Improved Mojo::Reactor::EV and Mojo::Reactor::Poll to fail more
    consistently.
  - Improved Mojo::Base performance slightly.
  - Fixed a few bugs in Mojo::DOM::CSS that required class, id and attribute
    selectors, as well as pseudo-classes, to be in a specific order.
  6.03  2015-03-16
  - Added support for overriding the HTTP request method with the _method query
    parameter.
  - Added suggested_method method to Mojolicious::Routes::Route.
  - Improved portability of some tests.
* Thu Mar 12 2015 coolo@suse.com
- updated to 6.02
  - Added daemon attribute to Mojo::Server::Morbo.
  - Improved portability of Mojo::Server::Morbo.
  - Fixed empty template handling in Mojo::Template.
  6.01  2015-03-03
  - Added content_with helper to Mojolicious::Plugin::DefaultHelpers.
  - Relaxed request-line handling in Mojo::Message::Request.
  - Fixed code name in version command and built-in templates.
* Fri Feb 27 2015 coolo@suse.com
- updated to 6.0
  - Code name "Clinking Beer Mugs", this is a major release.
  - Removed name listing support from param method in Mojolicious::Controller.
  - Removed name listing support from param method in Mojo::Parameters.
  - Removed name listing support from error and param methods in
    Mojolicious::Validator::Validation.
  - Removed multi-name support from cookie, param and signed_cookie methods in
    Mojolicious::Controller.
  - Removed multi-name support from param method in
    Mojolicious::Validator::Validation.
  - Removed multi-name support from param method in Mojo::Parameters.
  - Removed multi-name support from cookie and upload methods in Mojo::Message.
  - Removed custom socket support from Mojo::UserAgent.
  - Removed is_fatal, is_level and log methods from Mojo::Log.
  - Removed auto_render method from Mojolicious::Routes.
  - Removed deprecated object-oriented Mojo::Loader API.
  - Removed deprecated accept_interval, lock and unlock attributes from
    Mojo::IOLoop.
  - Removed deprecated accept_interval, lock_file and lock_timeout attributes
    from Mojo::Server::Prefork.
  - Removed deprecated bridge method from Mojolicious::Routes::Route.
  - Removed deprecated is_readable method from Mojo::Reactor.
  - Removed deprecated siblings method from Mojo::DOM.
  - Removed deprecated render_exception and render_not_found methods from
    Mojolicious::Controller.
  - Removed deprecated keep_alive_requests setting from Hypnotoad.
  - Changed return values of all and find methods in
    Mojo::UserAgent::CookieJar.
  - Renamed template attribute in Mojo::Template to unparsed.
  - Renamed extracting attribute in Mojo::UserAgent::CookieJar to collecting.
  - Renamed types attribute in Mojolicious::Types to mapping.
  - Renamed current attribute in Mojolicious::Routes::Match to position.
  - Renamed pattern attribute in Mojolicious::Routes::Route to unparsed.
  - Renamed all_contents, contents, following_siblings, match, next_sibling,
    node, preceding_siblings, previous_sibling and type methods in Mojo::DOM to
    descendant_nodes, child_nodes, following_nodes, matches, next_node, type,
    preceding_nodes, previous_node and tag.
  - Renamed match method in Mojo::DOM::CSS to matches.
  - Renamed extract and inject methods in Mojo::UserAgent::CookieJar to collect
    and prepare.
  - Renamed inject method in Mojo::UserAgent::Proxy to prepare.
  - Renamed params method in Mojo::Parameters to pairs.
  - Renamed match method in Mojolicious::Routes::Match to find.
  - Renamed -A option of prefork command to -a.
  - Added names method to Mojo::Parameters.
  - Added failed and passed methods to Mojolicious::Validator::Validation.
  - Added -I and -M options to prefork command.
  - Fixed Mojo::Template support for parentheses in expressions. (jberger, sri)
  5.82  2015-02-22
  - Deprecated Mojo::Reactor::is_readable.
  - Deprecated keep_alive_requests setting in Hypnotoad in favor of requests.
  - Improved Morbo to restart slightly faster.
  - Fixed bug in daemon and prefork commands where --inactivity-timeout option
    was called --inactivity.
  5.81  2015-02-20
  - Deprecated object-oriented Mojo::Loader API.
  - Added data_section, file_is_binary, load_class and find_modules functions
    to Mojo::Loader.
  - Improved design of built-in templates.
  - Fixed test command to not let Test::Harness enable global warnings by
    default. (OlegG)
* Sat Feb 14 2015 coolo@suse.com
- updated to 5.79
  - Fixed bug in Mojo::Reactor::Poll that caused excessive idle CPU usage.
  5.78  2015-02-12
  - Replaced expires method in Mojo::Cookie::Response with an attribute.
  - Added split_cookie_header function to Mojo::Util.
  - Updated IO::Socket::SSL requirement to 1.94.
  - Relaxed RFC 822/1123 and RFC 850/1036 handling in Mojo::Date.
  - Improved Mojo::Reactor::Poll performance significantly.
  - Improved text method in Mojo::Message to use default_charset as well.
  - Improved design of built-in templates.
  - Fixed bug in Mojo::DOM that made parsing a requirement.
  - Fixed warnings in Mojo::URL.
* Sat Feb  7 2015 coolo@suse.com
- updated to 5.77
  - Added content_security_policy method to Mojo::Headers.
  - Fixed canonicalize in Mojo::Path to not remove parts with more than three
    dots.
  5.76  2015-02-02
  - Emergency release for a critical security issue that can expose files on
    Windows systems, everybody should update!
  - Increased default max_message_size from 10MB to 16MB in Mojo::Message.
  - Reduced default max_line_size from 10KB to 8KB in Mojo::Headers and
    Mojo::Message.
  - Improved Hypnotoad load balancing by calling srand() after starting a new
    worker in Mojo::Server::Prefork.
  - Improved design of built-in templates.
  - Fixed bug in Mojo::IOLoop where the accept limit was applied too broadly.
  - Fixed bug in Mojo::Server::Prefork where the TTOU signal would not always
    stop a worker.
  - Fixed bug in Mojo::DOM::CSS where combinators needed to be surrounded by
    whitespace.
  5.75  2015-01-26
  - Added healthy method to Mojo::Server::Prefork.
  - Improved all built-in web servers to die if group or user assignment
    failed.
  - Improved Hypnotoad to wait for new workers to be ready before stopping the
    old ones during hot deployment.
  - Improved commands and log messages to use less punctuation.
  - Fixed bug in Mojo::IOLoop where the callback passed to next_tick would
    receive the wrong invocant.
  - Fixed race condition and memory leak in Mojo::Server::Prefork.
* Mon Jan 26 2015 coolo@suse.com
- updated to 5.74
  - Improved parser errors to be more consistent with connection errors in
    Mojo::Message::Request and Mojo::Message::Response.
  - Fixed "0" value bug in Mojo::Parameters.
  - Fixed bug where placeholder default values would not always have
    precedence.
  - Fixed proxy detection in get command.
  5.73  2015-01-24
  - Deprecated Mojolicious::Routes::Route::bridge in favor of
    Mojolicious::Routes::Route::under.
  - Deprecated Mojolicious::Controller::render_exception in favor of
    reply->exception helper.
  - Deprecated Mojolicious::Controller::render_not_found in favor of
    reply->not_found helper.
  - Removed deprecated object-oriented Mojo::JSON API.
  - Removed deprecated stringification support from Mojo::Collection.
  - Removed deprecated support for data arguments from Mojo::JSON::Pointer.
  - Removed deprecated AUTOLOAD and pluck methods from Mojo::Collection.
  - Removed deprecated AUTOLOAD and val methods from Mojo::DOM.
  - Moved tutorial from Mojolicious::Lite to Mojolicious::Guides::Tutorial.
  - Added term_escape method to Mojo::ByteStream.
  - Added term_escape function to Mojo::Util.
  - Improved get command to use the user agent of the application.
  - Improved diagnostics information for MOJO_DAEMON_DEBUG,
    MOJO_USERAGENT_DEBUG and MOJO_WEBSOCKET_DEBUG environment variables.
  - Fixed tag helpers to generate correct HTML5. (batman, sri)
  - Fixed JSON Pointer escaping bug.
  - Fixed portability bug in monkey_patch tests.
* Wed Jan 14 2015 coolo@suse.com
- updated to 5.72
  - Added EXPERIMENTAL support for case-insensitive attribute selectors like
    [foo="bar" i] to Mojo::DOM::CSS.
  - Added max_lines attribute to Mojo::Headers.
  - Improved Mojo::Reactor::EV to update the current time before starting a
    timer.
  - Improved error messages for start-line and header limits.
  - Fixed bug in Mojo::Headers where max_line_size was not checked correctly.
  - Fixed whitespace bug in Mojo::DOM::CSS.
  5.71  2015-01-01
  - Updated Net::DNS::Native requirement to 0.15 for some important bug fixes.
  - Updated jQuery to version 2.1.3.
  - Improved Mojo::URL performance.
  - Fixed fragment and userinfo normalization bugs in Mojo::URL.
  - Fixed query charset bug in Mojo::URL.
  - Fixed a few merge bugs in Mojo::Parameters.
* Thu Dec 18 2014 coolo@suse.com
- updated to 5.70
  - Improved Mojo::Template performance.
  - Fixed error handling bugs in Mojo::IOLoop::Stream.
  - Fixed a few limit bugs in Mojo::Message.
  - Fixed Windows bug in Mojo::IOLoop::Client. (OlegG)
  5.69  2014-12-13
  - Deprecated Mojo::DOM::siblings.
  - Added following, following_siblings, preceding and preceding_siblings
    methods to Mojo::DOM.
  - Added port method to Mojo::IOLoop::Server.
  - Removed deprecated emit_safe method from Mojo::EventEmitter.
  - Removed deprecated render_static method from Mojolicious::Controller.
  - Removed deprecated has_conditions method from Mojolicious::Routes::Route.
  - Updated Net::DNS::Native requirement to 0.14 for some important bug fixes.
  - Improved Mojo::DOM::HTML performance slightly.
  - Fixed parent combinator bug in Mojo::DOM::CSS.
  - Fixed whitespace bug in Mojo::DOM::HTML.
  - Fixed Mojo::UserAgent::Transactor to handle query parameters more like
    most common browsers.
  5.68  2014-12-02
  - Improved Mojo::DOM::CSS performance significantly.
  - Fixed deprecation warnings in get command.
  - Fixed bug in Mojolicious::Controller where sending a WebSocket message
    would cause multiple resume events.
  5.67  2014-11-27
  - Improved overall performance by deserializing sessions only on demand.
  - Fixed bug where embedded applications would deserialize sessions twice.
* Wed Nov 12 2014 coolo@suse.com
- updated to 5.60
  Tons of changes, just the peak of the ice berg:
  - Added to_array method to Mojo::Collection.
  - Added xss_escape function to Mojo::Util.
  - Updated Net::DNS::Native requirement to 0.12 for some important bug fixes.
  - Added support for non-blocking name resolution with Net::DNS::Native.
  5.58  2014-11-06
  - Improved error handling in Mojo::IOLoop::Client.
  5.57  2014-11-02
  - Deprecated stringification support in Mojo::Collection in favor of
    Mojo::Collection::join.
  - Deprecated Mojo::Collection::pluck in favor of Mojo::Collection::map.
  - Deprecated Mojo::DOM::val.
  - Improved map method in Mojo::Collection to be able to call methods.
  - Improved tap method in Mojo::Base to be able to call methods.
  5.56  2014-10-29
  - Deprecated Mojo::Collection::AUTOLOAD in favor of Mojo::Collection::pluck.
  - Deprecated Mojo::DOM::AUTOLOAD in favor of Mojo::DOM::children.
  5.55  2014-10-28
  - Deprecated support for data arguments in Mojo::JSON::Pointer.
  - Added access_control_allow_origin, content_language, content_location and
    strict_transport_security methods to Mojo::Headers.
  5.54  2014-10-23
  - Deprecated object-oriented Mojo::JSON API.
  - Added auto_decompress attribute to Mojo::Content.
  - Improved Mojo::Content to parse content more defensively.
  - Fixed chunked transfer encoding bug in Mojo::Content.
  - Fixed bug where Mojo::UserAgent would try to follow redirects for
    protocols other than HTTP and HTTPS.
  5.53  2014-10-20
  - Fixed bug in Mojo::Server where secondary groups were not reassigned
    correctly. (ksm, sri)
  5.52  2014-10-18
  - Fixed read-only file system compatibility of Mojo::Asset::File.
  5.51  2014-10-17
  - Fixed bug in Mojolicious::Validator::Validation where every_param would
    sometimes return an array reference containing an undef value.
  - Fixed Mojo::ByteStream and Mojo::Collection to always return true in
    boolean context.
  5.50  2014-10-15
  - Improved Mojo::DOM::HTML performance slightly.
  - Fixed description list parsing bug in Mojo::DOM::HTML. (Trelane)
  5.49  2014-10-10
  - Improved form content generator to allow custom content types.
  - Improved Mojo::Server to load applications consistently for all servers.
    (tianon, sri)
  - Fixed Mojolicious::Static to hide files without extensions in DATA
    sections.
  - Fixed inflate command to ignore files without extensions.
  - Fixed bug in Mojolicious::Routes::Route where formats could be rendered
    twice for embedded applications.
* Thu Jul 10 2014 coolo@suse.com
- updated to 5.12
  - Fixed a few multipart form handling bugs.
  - Fixed AUTOLOAD bug in Mojo::Collection where it would behave differently
    than calling pluck directly.
  5.11  2014-07-02
  - Moved reverse_proxy attribute from Mojo::Server::Daemon to Mojo::Server.
  - Added delay and inactivity_timeout helpers to
    Mojolicious::Plugin::DefaultHelpers.
  - Improved error method in Mojolicious::Validator::Validation to return
    field names when called without arguments.
  - Fixed "0" value bug in Mojo::UserAgent::Transactor.
  5.10  2014-06-28
  - Added cleanup attribute to Mojo::Server::Prefork.
  - Improved Mojo::Server::Prefork to keep sending heartbeat messages when
    stopping gracefully.
  - Fixed small bug where Mojo::Server::Daemon was too eager to reconfigure
    Mojo::IOLoop.
  - Fixed small bug where Hypnotoad would clean up process id and lock files
    too early.
  5.09  2014-06-24
  - Improved .ep templates to make the current controller available as $c.
* Tue Jun 17 2014 lnussel@suse.de
- update to 5.08
  5.08  2014-06-17
  - Added reset method to Mojo::IOLoop.
  - Added reset method to Mojo::Reactor.
  - Added reset method to Mojo::Reactor::Poll.
  5.07  2014-06-13
  - Fixed RFC 7230 compliance bugs in Mojo::Headers.
  5.06  2014-06-11
  - Added deserialize and serialize attributes to Mojolicious::Sessions.
  - Improved redirect_to to behave more like url_for.
  - Fixed bug in Mojo::UserAgent where HTTP/1.0 connections were sometimes
    kept alive.
  5.05  2014-06-08
  - Fixed parsing of header fields with single character names in
    Mojo::Headers. (crab)
  5.04  2014-06-03
  - Added expect_close attribute to Mojo::Content.
  - Improved support for broken responses to CONNECT requests.
  5.03  2014-06-02
  - Fixed bug where Mojo::DOM::HTML could not handle certain broken tags.
  5.02  2014-05-31
  - Added multi-name support to cookie and signed_cookie methods in
    Mojolicious::Controller.
  - Added multi-name support to cookie and upload methods in Mojo::Message.
  - Improved Mojolicious::Command::generate::plugin to use better directory
    names.
  - Fixed bug where Mojo::DOM::HTML could not handle tags with lots of
    attributes.
  5.01  2014-05-30
  - Fixed continuation line handling in Mojo::Headers.
  5.0  2014-05-29
  - Code name "Tiger Face", this is a major release.
  - Changed heuristics for number detection in Mojo::JSON to better line up
    with user expectations.
  - Changed lock and unlock callbacks in Mojo::IOLoop to not receive an
    invocant.
  - Changed return value of path_for method in Mojolicious::Routes::Match.
  - Changed return value and arguments of error method in Mojo::Message.
  - Removed deprecated support for "X-Forwarded-HTTPS".
  - Removed return values from wait method in Mojo::IOLoop::Delay.
  - Removed list context support from header method in Mojo::Headers.
  - Removed generate_port method from Mojo::IOLoop.
  - Replaced reserved stash value partial with render_to_string method.
  - Replaced format method in Mojo::Log with an attribute.
  - Replaced check_file method in Mojo::Server::Morbo with check method.
  - Added with_compression method to Mojo::Transaction::WebSocket.
  - Added catch method to Mojo::EventEmitter.
  - Added append method to Mojo::Log.
  - Updated jQuery to version 2.1.1.
  - Improved Mojo::IOLoop::Delay to automatically check if the event loop is
    already running.
  - Improved Mojo::Parameters to consistently accept arrays.
  - Improved Mojo::Collection to perform actual boolean checks. (marcus)
  - Fixed Mojo::DOM::HTML to handle slashes in unquoted attribute values
    correctly.
  - Fixed Mojo::IOLoop::Server to work correctly with newer versions of
    IO::Socket::SSL. (noxxi)
  - Fixed rendering bug where rewritten arguments could not be localized.
  - Fixed verification bug in Mojo::IOLoop::Server.
  - Fixed path generation bug in Mojolicious::Routes::Match.
  - Fixed warnings in Mojo::IOLoop::Delay.
  4.99  2014-05-12
  - Added support for performing blocking and non-blocking requests at the
    same time with Mojo::UserAgent.
  - Added nb_url method to Mojo::UserAgent::Server.
  - Improved Mojo::IOLoop::Server and Mojo::Server::Daemon to be able to
    listen on random ports.
  4.98  2014-05-09
  - Removed deprecated get_line function from Mojo::Util.
  - Removed deprecated content_xml, replace_content, text_before, text_after
    and to_xml methods from Mojo::DOM.
  - Improved accept performance in Mojo::IOLoop::Server.
  4.97  2014-04-30
  - Deprecated support for "X-Forwarded-HTTPS" in favor of
    "X-Forwarded-Proto".
  - Added multi-name support to param method in Mojo::Parameters.
  4.96  2014-04-28
  - Improved Mojo::IOLoop to use Mojo::IOLoop::Delay more consistently.
  4.95  2014-04-27
  - Improved Mojo::IOLoop::Delay with circular reference protection.
  - Improved Mojo::IOLoop::Delay to allow argument splicing.
  - Improved Mojo::IOLoop::Server to reuse cipher list from IO::Socket::SSL.
  - Fixed memory leak in Mojo::UserAgent::Server.
  4.94  2014-04-20
  - Added reverse_proxy attribute to Mojo::Server::Daemon.
  - Added reverse_proxy attribute to Mojo::Message::Request.
  - Added prefork and upgrade_timeout attributes to Mojo::Server::Hypnotoad.
  - Added configure method to Mojo::Server::Hypnotoad.
  - Relaxed name handling in Mojo::Headers a little.
  - Fixed small bug in online tests.
  4.93  2014-04-13
  - Fixed bug where Mojolicious::Static would not use the correct default MIME
    type.
  4.92  2014-04-08
  - Removed deprecated use of hash references for optgroup generation with
    select_field helper.
  - Improved dumper helper to escape unprintable characters.
  - Fixed small handler detection bug in Mojolicious::Renderer.
  4.91  2014-03-29
  - Added daemonize method to Mojo::Server.
  - Added ensure_pid_file method to Mojo::Server::Prefork.
  - Removed deprecated secret method from Mojolicious.
  - Improved performance of Mojolicious::Plugin::EPRenderer and
    Mojolicious::Plugin::EPLRenderer.
  - Improved Mojo::Reactor::Poll portability with POLLPRI support.
* Sat Mar 22 2014 coolo@suse.com
- updated to 4.90
  - Removed deprecated to_rel method from Mojo::URL.
  - Updated IO::Socket::SSL requirement to 1.84 due to breaking changes in
    IO::Socket::SSL.
  - Improved documentation browser with more accessible links and readable
    inline code.
  - Fixed textarea and title parsing bugs in Mojo::DOM::HTML.
  4.89  2014-03-13
  - Added support for template variants.
  - Improved built-in templates with unobtrusive menu bar.
  - Fixed bug in Mojo::DOM::HTML where non-self-closing elements were not
    handled correctly.
  - Fixed bug in Mojo::DOM::HTML where <image> was not treated as an alias for
    <img>.
  4.88  2014-03-09
  - Added build_controller method to Mojolicious.
  - Added match method to Mojolicious::Routes.
  - Improved Mojo::Server::Daemon to handle setuid/setgid errors more
    gracefully.
  - Improved Mojo::Server::Prefork to handle lock file errors more gracefully.
  - Improved exception page to show better context information for templates.
  - Fixed comment on last line bug in Mojo::Template.
  4.87  2014-03-04
  - Improved Mojo::ByteStream to allow more method chaining.
  - Fixed RFC 7159 support in Mojo::JSON.
  - Fixed RFC 7159 compliance bugs in Mojo::Transaction::WebSocket and
    Test::Mojo.
  - Fixed Unicode bugs in Test::Mojo.
  4.86  2014-03-03
  - Improved Mojo::IOLoop::Delay to allow more method chaining.
  - Improved WebSocket and long poll performance.
  ... and tons more, see Changes
* Wed Jan 29 2014 alarrosa@suse.com
- updated to 4.70.
* Sat Jul 27 2013 coolo@suse.com
- updated to 4.19, complete new code
* Mon Dec 26 2011 pascal.bleser@opensuse.org
- update to 2.40:
  * added EXPERIMENTAL JSON Pointer support
  * improved inactivity timeouts by allowing them to be disabled
  * improved class detection of inflate command
  * fixed small bug in Mojo::IOLoop::Server that prevented TLS tests from
    running parallel
  * fixed repository to not favor specific editors
- changes from 2.39:
  * deprecated all keep_alive_timeout attributes and parameters in favor of
    inactivity_timeout
  * added EXPERIMENTAL error event to Mojo::UserAgent
  * added EXPERIMENTAL local_address attribute to Mojo::UserAgent
  * added EXPERIMENTAL local_address option to Mojo::IOLoop::Client->connect
  * added EXPERIMENTAL close method to Mojo::IOLoop::Stream
  * added "hello.pl" and "fast.pl" to example scripts
  * removed log attribute from Mojo::UserAgent
  * removed MOJO_STATIC_CLASS and MOJO_TEMPLATE_CLASS environment variables
  * fixed Morbo to ignore hidden directories
  * fixed small argument bug in client method of Mojo::IOLoop
  * fixed small memory leak in Mojo::IOLoop::Stream
  * fixed multiple small error reporting bugs in Mojo::UserAgent
  * fixed online tests to not be affected by geographical location
- changes from 2.38:
  * changed Mojo::IOLoop->client arguments from ($loop, $stream, $err) to
    ($loop, $err, $stream)
  * improved resilience of Mojo::IOLoop::Stream
  * fixed memory leaks caused by named capture groups bug in Perl
  * fixed small cleanup bug in Mojo::Asset::File
  * fixed small multipart bug in Mojo::Message
  * fixed missing status method in Mojo::Headers
  * fixed small Mojo::IOLoop::Stream timeout bug
* Mon Dec 12 2011 pascal.bleser@opensuse.org
- update to 2.37:
  * removed cleanup_interval attribute from Mojo::IOLoop
  * deprecated Mojo::IOLoop->timeout in favor of Mojo::IOLoop::Stream->timeout
  * added EXPERIMENTAL timeout event to Mojo::IOLoop::Stream
  * added EXPERIMENTAL timeout attribute to Mojo::IOLoop::Stream
  * changed default keep alive timeout of Mojo::UserAgent from 15 to 20 seconds
  * improved unicode tests.
  * fixed inline template double encoding bug
- changes from 2.36:
  * changed default heartbeat timeout of Hypnotoad from 5 to 10 seconds
  * fixed default keep alive timeout of Hypnotoad
* Sat Dec  3 2011 pascal.bleser@opensuse.org
- update to 2.35:
  * added EXPERIMENTAL etag method to Mojo::Headers
  * fixed one-byte payload bug in Mojo::Transaction::WebSocket
  * fixed body event in Mojo::Content to work more reliably in CGI environments
  * fixed small portability issue in loader test
* Wed Nov 30 2011 pascal.bleser@opensuse.org
- update to 2.34:
  * added "websocket.pl" to example scripts
  * fixed small bugs in example scripts
- changes from 2.33:
  * improved Mojo::EventEmitter performance slightly
  * fixed a few small inline template issues
  * fixed small WebSocket handshake bug
- changes from 2.32:
  * added EXPERIMENTAL error event to Mojo::IOWatcher
  * updated jQuery to version 1.7.1
  * improved Mojo::IOLoop performance by changing the default cleanup interval
    from 0 to 0.025 seconds
* Mon Nov 21 2011 pascal.bleser@opensuse.org
- update to 2.31:
  * improved stacktraces by making them a lot simpler
  * improved tests
* Sun Nov 20 2011 pascal.bleser@opensuse.org
- update to 2.30:
  * deprecated Mojo::IOLoop->on_lock in favor of Mojo::IOLoop->lock
  * deprecated Mojo::IOLoop->on_unlock in favor of Mojo::IOLoop->unlock
- changes from 2.29:
  * deprecated Mojolicious->on_process in favor of around_dispatch hook
  * added EXPERIMENTAL emit_chain method to Mojolicious::Plugins
  * added EXPERIMENTAL around_dispatch hook
  * fixed small bug in boundary and charset methods of Mojo::Content
* Fri Nov 18 2011 pascal.bleser@opensuse.org
- update to 2.28:
  * fixed small IPv6 portabilty issue in Mojo::IOLoop::Client
- changes from 2.27:
  * deprecated Mojo::IOLoop->connect in favor of Mojo::IOLoop->client
  * deprecated Mojo::IOLoop->listen in favor of Mojo::IOLoop->server
  * deprecated Mojo::IOLoop->connection_timeout in favor of
    Mojo::IOLoop->timeout
  * deprecated Mojo::IOLoop->write in favor of Mojo::IOLoop::Stream->write
  * deprecated Mojo::IOLoop->connect_timeout in favor of timeout argument
  * deprecated on_* methods in Mojo::IOLoop
  * removed Mojo::IOLoop::Resolver
  * added EXPERIMENTAL connect_timeout attribute to Mojo::UserAgent
  * added EXPERIMENTAL is_readable method to Mojo::IOLoop::Stream
  * added EXPERIMENTAL charset method to Mojo::Content
  * added EXPERIMENTAL write event to Mojo::IOLoop::Stream
  * added EXPERIMENTAL connection event to Mojo::Transaction
  * improved CSS of some built-in templates
  * fixed many small memory leaks
  * fixed multiple drain callback bugs
  * fixed small attribute selector bug in Mojo::DOM::CSS
* Fri Nov 11 2011 pascal.bleser@opensuse.org
- update to 2.26:
  * added EXPERIMENTAL upgrade event to Mojo::Asset::Memory
  * added EXPERIMENTAL upgrade event to Mojo::Transaction::HTTP
  * added EXPERIMENTAL auto_upgrade attribute to Mojo::Asset::Memory
  * improved Mojo::Content::Single and Mojo::Content::MultiPart parsers to
    reuse events
  * fixed small route caching bug
* Wed Nov  9 2011 pascal.bleser@opensuse.org
- update to 2.25:
  * removed canonicalize method from Mojo::URL
  * fixed URL without scheme handling in Mojo::URL
  * fixed a few small bugs in Mojo::URL
* Sun Nov  6 2011 pascal.bleser@opensuse.org
- update to 2.24:
  * added EXPERIMENTAL canonicalize method to Mojo::URL
  * fixed small path canonicalization bug in Mojo::URL
  * fixed small trailing slash bug in Mojo::Path
- changes from 2.23:
  * changed semantics of get_line function in Mojo::Util
  * removed experimental status from Mojo::Util
  * updated jQuery to version 1.7
  * improved empty path element handling in Mojo::URL
  * fixed empty path element bug in Mojo::Path
* Thu Nov  3 2011 pascal.bleser@opensuse.org
- update to 2.22:
  * added EXPERIMENTAL --verbose flag to routes command
  * fixed a few attribute without value selector bugs in Mojo::DOM::CSS
  * fixed template inheritance bug in Mojolicious::Renderer
* Thu Nov  3 2011 pascal.bleser@opensuse.org
- update to 2.21:
  * removed profile helper
  * removed CSS4 selector subject support from Mojo::DOM::CSS until we actually
    know the exact semantics
  * improved Mojo::ByteStream to generate most Mojo::Util based methods
    automatically
  * fixed route pattern bug
* Tue Nov  1 2011 pascal.bleser@opensuse.org
- update to 2.20:
  * changed semantics of almost all functions in Mojo::Util
  * documentation improvements
* Mon Oct 31 2011 pascal.bleser@opensuse.org
- update to 2.19:
  * deprecated Mojolicious::Plugins->add_hook in favor of
    Mojolicious::Plugins->on
  * deprecated Mojolicious::Plugins->run_hook in favor of
    Mojolicious::Plugins->emit_hook
  * deprecated Mojolicious::Plugins->run_hook_reverse in favor of
    Mojolicious::Plugins->emit_hook_reverse
  * improved documentation
  * improved tests
- changes from 2.18:
  * fixed small rendering bug
* Sun Oct 30 2011 pascal.bleser@opensuse.org
- update to 2.17:
  * removed experimental status from Mojo::EventEmitter
  * merged unsubscribe and unsubscribe_all methods in Mojo::EventEmitter
* Sun Oct 30 2011 pascal.bleser@opensuse.org
- update to 2.15
* Tue Jun 14 2011 pascal.bleser@opensuse.org
- update to 1.43:
  * improved after_dispatch hook by allowing it to change session data
  * fixed a bug in Mojo::Template that caused template blocks to be auto
    escaped
* Thu Jun  9 2011 pascal.bleser@opensuse.org
- update to 1.42:
  * added EXPERIMENTAL support for unquoted wildcard placeholders in
    Mojolicious::Routes::Pattern
  * added EXPERIMENTAL status code support to rendred method in
    Mojolicious::Controller
  * updated WebSocket implementation to ietf-08
  * improved layout tests
  * improved documentation
  * fixed a bug that prevented Mojo::Base subclasses from using the "-base"
    flag
  * fixed a few small default status code bugs
  * fixed route suggestion bug in "not_found.development.html.ep"
  * fixed typos
* Sat Jun  4 2011 pascal.bleser@opensuse.org
- update to 1.41:
  * fixed param list bug in Mojolicious::Controller
  * fixed overload bug in Mojo::DOM
- changes from 1.4:
  * deprecated Mojo::DOM add_after method in favor of the append method
  * deprecated Mojo::DOM add_before method in favor of the prepend method
  * deprecated all methods containing the word "inner" in favor of ones
    containing the word "content"
  * added EXPERIMENTAL direct hash access for attributes and child element
    accessor support to Mojo::DOM
  * added EXPERIMENTAL support for collections to children method and element
    accessors in Mojo::DOM
  * added EXPERIMENTAL to_xml method to Mojo::DOM collections
  * added EXPERIMENTAL eval command
  * added EXPERIMENTAL load_app method to Mojo::Server
  * added append_content and prepend_content methods to Mojo::DOM
  * added HTTP method support to routes command
  * improved long poll support
  * improved documentation
  * improved compatibility with Feersum PSGI web servers
  * switched from Storable to JSON serialization for Mojolicious sessions to
    increase efficiency
  * reduced memory usage of Hypnotoad workers by at least 1MB (each)
  * fixed a small Mojo::Loader bug
  * fixed small Windows line ending problem in Mojo::Command
  * fixed a UTF-8 bug in Mojo::Exception
  * fixed "Can't locate object method x via package y" error messages
  * fixed woff MIME type
* Sun May 22 2011 pascal.bleser@opensuse.org
- update to 1.34:
  * fixed nested selector bug in Mojo::DOM
  * fixed small Mojo::DOM HTML5 bug
- changes from 1.33:
  * added EXPERIMENTAL helper function to Mojolicious::Lite
  * updated jQuery to version 1.6.1
  * improved Mojo::JSON string escaping to make JSONP easier
  * improved reloader slightly
  * moved all bundled templates to "lib/Mojolicious/templates"
  * fixed reserved GET/POST param handling in Mojolicious::Controller
  * fixed small XML semantics bug in Mojo::DOM
  * fixed all blocking server bindings to default to a 404 status code
* Tue May 17 2011 pascal.bleser@opensuse.org
- update to 1.32:
  * updated IO::Socket::SSL requirement to 1.43 due to bugs in older versions
  * improved reloading slightly by allowing it to clean up the main namespace
  * fixed enabling of Perl 5.10 features in Mojo::Base and Mojolicious::Lite
  * fixed render_later to prevent delayed rendering warning
* Sun May  8 2011 pascal.bleser@opensuse.org
- update to 1.31:
  * reverted deprecation of Perl 5.8.x support, by popular demand
  * added FAQ entry to clarify the Perl 5.8.x situation
  * improved documentation
  * fixed case sensitivity of Mojo::DOM in XML mode
  * fixed pseudo class case handling in Mojo::DOM
* Fri May  6 2011 pascal.bleser@opensuse.org
- update to 1.3:
  * deprecated Perl 5.8.x support.
  * deprecated Mojolicious::Renderer get_inline_template method in favor of the
    get_data_template method
  * added EXPERIMENTAL before_render hook.
  * added EXPERIMENTAL hook function to Mojolicious::Lite
  * added workaround for uWSGI bug
  * improved Mojo::Template and Mojolicious::Routes exception handling
  * improved debug log messages for template rendering
  * updated Mojo::Base and Mojolicious::Lite to enable Perl 5.10 features if
    available
  * updated jQuery to version 1.6
  * fixed PSGI read error handling
  * fixed 64bit WebSocket message bug
* Mon May  2 2011 pascal.bleser@opensuse.org
- update to 1.22:
  * deprecated Mojo::IOLoop on_tick method in favor of the recurring method
  * deprecated Mojo::IOLoop on_hup method in favor of the on_close method
  * deprecated on_build_tx methods in favor of on_transaction methods
  * deprecated on_handler methods in favor of on_request methods
  * updated WebSocket implementation to ietf-07
  * renamed on_idle method in Mojo::IOLoop to idle
  * reduced memory requirements of cached templates by up to 50%%
  * fixed controller specific render_exception and render_not_found methods
  * fixed Mojo::JSON string size limit
  * fixed small memory leak
  * fixed small stack localization bug
  * fixed small tag helper escaping bug
* Thu Apr 28 2011 pascal.bleser@opensuse.org
- update to 1.21:
  * improved temporary file handling to avoid a very unlikely race condition
  * fixed "multipart/form-data" generation bug in Mojo::UserAgent
- changes from 1.20:
  * improved size limit handling
* Wed Apr 20 2011 pascal.bleser@opensuse.org
- update to 1.19:
  * fixed size limits in message parser
- changes from 1.18:
  * added support for "X-Forwarded-HTTPS" and "X-Forwarded-Host" headers
  * added argument localization to the include helper
  * improved documentation
- changes from 1.17:
  * deprecated Mojolicious process method in favor of the on_process attribute
  * added Failraptor
  * added support for MOJO_CERT_FILE and MOJO_KEY_FILE environment variables
  * added EXPERIMENTAL xml attribute to Mojo::DOM
  * added EXPERIMENTAL build_url method to Test::Mojo
  * added EXPERIMENTAL dnt (Do Not Track) method to Mojo::Headers
  * added WOFF mime type
  * updated WebSocket implementation to ietf-06
  * updated jQuery to version 1.5.2
  * improved HTML healing capabilities of Mojo::DOM
  * improved Mojo::DOM to ignore useless end tags
  * improved Mojo::DOM inline DTD support
  * improved Mojo::DOM text extraction
  * improved Mojolicious::Plugin::I18n default lexicon handling
  * improved a Mojo::IOLoop workaround
  * moved all bundled static files to "lib/Mojolicious/public"
  * fixed small CGI/FastCGI header generation bug
  * fixed readonly handle support in Mojo::IOLoop
  * fixed a Mojo::IOLoop resolver bug
  * fixed small Mojo::Asset::File bug
  * fixed small Mojo::DOM selector bug
  * fixed small Mojo::DOM namespace detection bug
  * fixed small route pattern escaping bug
  * fixed small reload bug
  * fixed small perldoc browser bug
  * fixed cookbook recipe
* Sat Apr 16 2011 pascal.bleser@opensuse.org
- update to 1.16:
  * emergency release for a critical security issue that can expose files on
    your system, everybody should update!
- changes from 1.15:
  * changed default log level in "production" mode from "error" to "info"
  * improved lookup method in Mojo::IOLoop
  * fixed a serious Mojo::DOM bug
* Thu Mar 17 2011 pascal.bleser@opensuse.org
- update to 1.14:
  * added support for multiple dns servers to Mojo::IOLoop
  * added config helper to Mojolicious::Plugin::Config
  * changed resolv.conf parser in Mojo::IOLoop to use the first nameserver
  * changed lookup method in Mojo::IOLoop to pick records randomly
  * fixed small optional tag bugs in Mojo::DOM
  * fixed JavaScript/CSS bug in Mojo::DOM
* Mon Mar 14 2011 pascal.bleser@opensuse.org
- update to 1.13:
  * deprecated Mojo::Client in favor of the much sleeker Mojo::UserAgent
  * made the most common Mojo::IOLoop methods easier to access for the
    singleton instance
* Fri Mar 11 2011 pascal.bleser@opensuse.org
- update to 1.12:
  * relicensed all artwork to CC-SA, so the whole distribution can be
    considered "open" again
  * deprecated MOJO_JSON_CONFIG environment variable in favor of MOJO_CONFIG
  * added EXPERIMENTAL support for IPv6
  * added more Perl-ish configuration plugin
  * added drain callback support for WebSockets
  * added line numbers to Mojo::JSON error messages
  * removed experimental status from hypnotoad and Mojolicious::Plugin::TagHelpers
  * removed experimental status from many attributes and methods all over
    Mojolicious
  * improved attribute support of the select_field tag helper
  * improved text_field tag helper
  * improved tag helper attribute escaping
  * improved attrs method in Mojo::DOM
  * updated to jQuery to version 1.5.1
  * fixed XSS issue in link_to helper
  * fixed route unescaping bug
  * fixed small Mojo::DOM bug
  * fixed small documentation bug
* Fri Feb 18 2011 pascal.bleser@opensuse.org
- initial version (1.11)
